(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2626043,      44883]*)
(*NotebookOutlinePosition[   2626974,      44917]*)
(*  CellTagsIndexPosition[   2626868,      44910]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Initialisation", "Section"],

Cell["<< LinearAlgebra`MatrixManipulation`", "Input",
  CellTags->"S5.48.1"],

Cell[BoxData[
    \(<< LinearAlgebra`Orthogonalization`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`MultipleListPlot`\)], "Input"],

Cell[BoxData[
    \(KroneckerProduct[a_?SquareMatrixQ, b_?SquareMatrixQ] := 
      BlockMatrix[Outer[Times, a, b]]\)], "Input",
  CellTags->"Outer"],

Cell["Graphe for two populations", "Text"],

Cell[BoxData[
    \(OnePopEigenvalueT[\[Alpha]_, \[Beta]_, e1_, e2_, n1_, 
        n2_] := \(1\/\(2\ n1\ n2\)\) \((\(-n2\)\ \[Alpha] + 
            e1\ n2\ \[Alpha] + n1\ n2\ \[Alpha] - e1\ n1\ n2\ \[Alpha] - 
            n1\ \[Beta] + e2\ n1\ \[Beta] + n1\ n2\ \[Beta] - 
            e2\ n1\ n2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + 
                        e1)\)\ \((\(-1\) + e2)\)\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \[Alpha] + \[Beta])\) + \((\((\
\(-1\) + e2)\)\ n1\ \[Beta] - n2\ \((\((\(-1\) + e1)\)\ \((\(-1\) + n1)\)\ \
\[Alpha] + \((\(-1\) + e2)\)\ n1\ \[Beta])\))\)\^2)\))\)\)], "Input"],

Cell[BoxData[
    \(OnePopEigenvaluePo[\[Alpha]_, \[Beta]_, e1_, e2_] := 
      1\/2\ \((\[Alpha] - e1\ \[Alpha] + \[Beta] - 
            e2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + e1)\)\ \((\(-1\) + 
                        e2)\)\ \((\(-1\) + \[Alpha] + \[Beta])\) + \((\((\(-1\
\) + e1)\)\ \[Alpha] + \((\(-1\) + e2)\)\ \[Beta])\)\^2)\))\)\)], "Input"],

Cell[BoxData[
    \(GrapheOnePopThreeStates[yinf_, ysup_, \[Alpha]_, \[Beta]_, e1_, e2_, 
        n1_, n2_] := 
      Plot[{OnePopEigenvaluePo[\[Alpha], \[Beta], e1, e2], 
          OnePopEigenvalueT[\[Alpha], \[Beta], e1, e2, n1, n2], 
          OnePopEigenvalueT[\[Alpha], \[Beta], e1, e2, n1, \
n2]\/OnePopEigenvaluePo[\[Alpha], \[Beta], e1, e2]}, {x, 0, 1}, 
        PlotRange \[Rule] {{0, 1}, {yinf, ysup}}, 
        PlotStyle -> {Dashing[{0.05, 0.05}], Dashing[{0, 0}], 
            Dashing[{0.01, 0.01, 0.01, 0.01}]}, 
        Frame \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(Clear[GrapheTwoSpom]\)], "Input"],

Cell[BoxData[
    \(GrapheTwoSpom[yinf_, ysup_, b_, d_, e1_, e2_, n1_, n2_] := 
      Plot[{Eigenvalues[TwoSpomPoMatrix[b, d, e1, e2, n1, n2], 1], 
          Eigenvalues[TwoSpomTMatrix[b, d, e1, e2, n1, n2], 1], 
          Eigenvalues[TwoSpomTMatrix[b, d, e1, e2, n1, n2], 1]/
            Eigenvalues[TwoSpomPoMatrix[b, d, e1, e2, n1, n2], 1]}, {x, 0, 
          1}, PlotRange \[Rule] {{0, 1}, {yinf, ysup}}, 
        PlotStyle -> {Dashing[{0.05, 0.05}], Dashing[{0, 0}], 
            Dashing[{0.01, 0.01, 0.01, 0.01}]}, 
        Frame \[Rule] True]\)], "Input"],

Cell["Graphe for three populations", "Text"],

Cell[BoxData[
    \(GrapheThreeSpom[yinf_, ysup_, b_, d_, e1_, e2_, e3_, n1_, n2_, 
        n3_, \[CapitalLambda]13_, \[CapitalLambda]12_, \[CapitalLambda]21_] := 
      Plot[{Eigenvalues[
            ThreeSpomPoMatrix[b, d, e1, e2, e3, n1, n2, 
              n3, \[CapitalLambda]13, \[CapitalLambda]12, \
\[CapitalLambda]21], 1], 
          Eigenvalues[
            ThreeSpomTMatrix[b, d, e1, e2, e3, n1, n2, 
              n3, \[CapitalLambda]13, \[CapitalLambda]12, \
\[CapitalLambda]21], 1], 
          Eigenvalues[
              ThreeSpomTMatrix[b, d, e1, e2, e3, n1, n2, 
                n3, \[CapitalLambda]13, \[CapitalLambda]12, \
\[CapitalLambda]21], 1]/
            Eigenvalues[
              ThreeSpomPoMatrix[b, d, e1, e2, e3, n1, n2, 
                n3, \[CapitalLambda]13, \[CapitalLambda]12, \
\[CapitalLambda]21], 1]}, {x, 0, 1}, 
        PlotRange \[Rule] {{0, 1}, {yinf, ysup}}, 
        PlotStyle -> {Dashing[{0.05, 0.05}], Dashing[{0, 0}], 
            Dashing[{0.01, 0.01, 0.01, 0.01}]}, 
        Frame \[Rule] True]\)], "Input"],

Cell[CellGroupData[{

Cell["Matrices", "Subsubsection"],

Cell[BoxData[
    \(TwoSpomPoMatrix[b_, d_, e1_, e2_, n1_, 
        n2_] := {{\((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - e2)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                      e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                      e2)\) - 
                e2)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) - 
                e2)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                      e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                      e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
                e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) + 
                e2)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                      e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                      e2)\) - 
                e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) - e2)\)}}\)], "Input"],

Cell[BoxData[
    \(TwoSpomTMatrix[b_, d_, e1_, e2_, n1_, 
        n2_] := {{0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ \
n2)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                        e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 0, 
          0, \(1\/\((n1 - d\ n1 + d\ n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(-\(\
\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(\(1\/\((\(-n2\) + d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - e2)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)\), \(\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\
\ n1\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 \
- e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/n1, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\(-d\)\ n1 + \((\(-1\) + d)\)\ n2)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(1\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2)\)}, {0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ \
n2)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                        e2)\) + e2)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 0, 
          0, \(1\/\((n1 - d\ n1 + d\ n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + 
                      e2)\)\ n1\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(-\(\
\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + 
                      e2)\)\ n1\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 \
- e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
                    e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
                    e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(\(1\/\((\(-n2\) + d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 \
- e2)\) + e2)\)\ \((\(-1\) + n1)\)\)\/n1, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\(-d\)\ n1 + \((\(-1\) + d)\)\ n2)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + 
                      e2)\)\ n1\ n2)\)/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + 
                      e2)\)\ n1\ n2)\)/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(1\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n2)\)\ n2)\)}, {0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ \
n2)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                        e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 0, 
          0, \(1\/\((n1 - d\ n1 + d\ n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2)\)\^2\) \((\
\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ \
n2)\)\^2\) \((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)\)\), \((d\^2\ \((1 - \[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(-\(\(1\/\(\((\(-1\) + d)\)\ n2\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\))\)\)\), \(-\(\(1\/\(\((\(-1\) + 
                      d)\)\ n1\)\)\((\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\))\)\)\), 0, 0, 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((\((d\ n1 - \((\(-1\) + 
                          d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2)\))\)}, {0, 0, 
          0, \(\(1\/\((\(-n2\) + d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - e2)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \
\((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/n1, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((\(-d\)\ n1 + \((\(-1\) + d)\)\ n2)\)\^2, \
\(-\(\(1\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\) \((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)\)\), \(-\(\(1\/\((\(-d\)\ n1 - n2 + d\ \
n2)\)\^2\) \((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - 
                      e2)\)\ n1\ n2)\)\)\), \(1\/\((\(-d\)\ n1 - n2 + d\ \
n2)\)\^2\) \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2)\)}}\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\
\)\)], "Input"],

Cell[BoxData[
    \(ThreeSpomPoMatrix[b_, d_, e1_, e2_, e3_, n1_, n2_, 
        n3_, \[CapitalLambda]13_, \[CapitalLambda]12_, \[CapitalLambda]21_] := \
{{\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 \
- e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\)}, {\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 \
- e3)\) + 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 \
- e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
                e3)\)}, {\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 \
- e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - 
                e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 \
- e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
                e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 \
- e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
                e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - 
                e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                      e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)}}\)], "Input"],

Cell[BoxData[
    \(ThreeSpomTMatrix[b_, d_, e1_, e2_, e3_, n1_, n2_, 
        n3_, \[CapitalLambda]13_, \[CapitalLambda]12_, \[CapitalLambda]21_] := \
{{0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\
\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\
\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\
\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) + 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\
\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) + 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
          0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 \
+ d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
          0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - \
d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + \
d\ n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \[CapitalLambda]13)\)/\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\
\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                    d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                    d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                  d\ n1\)\)\((\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \[CapitalLambda]21)\)/\
\((\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                            d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + d)\)\
\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\
\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 
          0, 0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
          0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
+ \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
          0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - \
d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 \
- d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\
\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 \
- d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\
\) + d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                            d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1)\)\ \((d\ n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 \
- d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) \
+ d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 
          0, 0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
          0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                    d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \
\(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                      d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                      d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                      d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                  d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\)\), 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 
          0, 0, \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ \
n3\ \((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                      e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                      d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\
\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                            e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                      d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                    
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                            d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                    d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                    d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                      d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                            e1)\) - 
                      e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2 - b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                      e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3 - b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                      n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\
\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                      d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                      d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                      d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 
          0, 0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \
\((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
          0, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \
\((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, 
          0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - \
d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 
          0, 0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\
\) + \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}}\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphs", "Section"],

Cell[CellGroupData[{

Cell["OnePopTreeStates", "Subsection"],

Cell["\<\
\[Beta]: proba of remaining in pop 1
\[Alpha]: proba of remaining in pop 2
e1: proba of extinction from pop 1
e2: proba of extinction from pop 2
n1: size of pop 1
n2: size of pop 2\
\>", "Text"],

Cell[BoxData[
    \(\([yinf_, ysup_, \[Alpha]_, \[Beta]_, e1_, e2_, n1_, n2_]\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheOnePopThreeStates[0, 1, 0.2, 0.5, 0.3, x, 3, 5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .54321 m
.04057 .5286 L
.08481 .51256 L
.12636 .49739 L
.16632 .48269 L
.20885 .46692 L
.2498 .4516 L
.29331 .43516 L
.33524 .41916 L
.37557 .40359 L
.41848 .38681 L
.4598 .37043 L
.49953 .35444 L
.54183 .33712 L
.58254 .32013 L
.62583 .30165 L
.66752 .28338 L
.70762 .26528 L
.7503 .24533 L
.79139 .22527 L
.83505 .20275 L
.87712 .17943 L
.9176 .15471 L
.96065 .12412 L
1 .08652 L
s
[ ] 0 setdash
0 .40939 m
.04057 .398 L
.08481 .38549 L
.12636 .37368 L
.16632 .36224 L
.20885 .34997 L
.2498 .33808 L
.29331 .32532 L
.33524 .31291 L
.37557 .30084 L
.41848 .28786 L
.4598 .2752 L
.49953 .26286 L
.54183 .24951 L
.58254 .23642 L
.62583 .22222 L
.66752 .20819 L
.70762 .19433 L
.7503 .17907 L
.79139 .16375 L
.83505 .1466 L
.87712 .12886 L
.9176 .11008 L
.96065 .0868 L
1 .05768 L
s
[ .01 .01 .01 .01 ] 0 setdash
0 .46579 m
.04057 .46534 L
.08481 .46482 L
.12636 .46432 L
.16632 .46381 L
.20885 .46324 L
.2498 .46267 L
.29331 .46203 L
.33524 .46137 L
.37557 .4607 L
.41848 .45994 L
.4598 .45915 L
.49953 .45834 L
.54183 .45741 L
.58254 .45644 L
.62583 .45529 L
.66752 .45406 L
.70762 .45273 L
.7503 .45111 L
.79139 .44926 L
.83505 .44686 L
.87712 .44384 L
.9176 .43974 L
.93853 .43673 L
.94921 .43479 L
.96065 .43224 L
.9713 .42919 L
.981 .4255 L
.98567 .42322 L
.99076 .42018 L
.99556 .41651 L
1 .41202 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003o
i/b0onK<P03nonK<P0?o00001OoVc80001Ooi/b000?o0000onK<P?oVc800o?oVc802o`0000;oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800nooVc8000ol0003oi/b0onK<
P002onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?[oi/b000?o0000
onK<P?oVc8000ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03honK<
P0;o00001_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03gonK<P003
o`000?oVc83oi/b000Koi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
mOoVc802o`0000Woi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800looV
c802o`0000[oi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03aonK<P0;o00003?oVc802
o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00>ooi/b00_l0000?onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00>goi/b00_l0000AonK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00>_oi/b00_l0000ConK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00>Woi/b00_l0000EonK<P003o`000?oVc83oi/b000?oi/b00003
onK<P0;o00001?oVc8001?l0003oi/b0onK<P?oVc805o`0000Goi/b000?o0000onK<P?oVc800iooV
c802o`0001Ooi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oV
c8001?l0003oi/b0onK<P?l00005onK<P003o`000?oVc83oi/b00>Goi/b00_l0000IonK<P003o`00
0?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Woi/b000?o0000onK<P?oVc800
1OoVc8000ol0003oi/b0onK<P03SonK<P0;o00006ooVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l0000:onK<P003o`000?oVc83oi/b000Coi/b00_l0003RonK<P0;o0000
4OoVc802o`0000Soi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`00
0?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03OonK<P0;o00004_oVc8000ol0003o
i/b0onK<P00:onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Oo
i/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00=goi/b00_l0000ConK<
P003o`000?oVc83oi/b000_oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00009onK<P0?o
00001_oVc8000ol0003oi/b0onK<P03JonK<P0?o00005?oVc8000ol0003oi/b0onK<P00<onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00=Soi/b00_l0000EonK<P0;o0000
3ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03FonK<P0;o00005_oV
c8000ol0003oi/b0onK<P00?onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00=Coi/b00_l0000GonK<P003o`000?oVc83oi/b0013oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800dOoVc803o`0001Soi/b000?o0000onK<P?oVc8004OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03>onK<P0?o00006_oVc8000ol0003o
i/b0onK<P00AonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800booVc803o`0003;oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800bOoVc802o`0003Goi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800a_oVc803o`0003Ooi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800`ooVc803o`0003[oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800`?oVc803o`0003goi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800__oVc802o`0001ooi/b00_l0000OonK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;_oi/b00ol0000OonK<P0;o00008OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P02honK<P0?o00008?oVc802
o`0002;oi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P02eonK<P0?o00008_oVc8000ol0
003oi/b0onK<P00SonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;?o
i/b00_l0000SonK<P0;o00009_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P02`onK<P0?o00008ooVc802o`0002Soi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800[_oVc802o`0002Goi/b000?o0000onK<P?oVc800:?oVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P02[onK<P0?o00009_oVc8000ol0003oi/b0onK<P00Y
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:Soi/b00ol0001EonK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:Coi/b01?l0001HonK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:7oi/b00ol0001KonK<P0;o0000
1OoVc80001Ooi/b000?o0000onK<P?oVc800W_oVc803o`0005ooi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800VooVc803o`0006;oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800V?oVc803o`0002goi/b00_l0000fonK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b009Goi/b00ol0000]onK<P0?o0000>?oVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800T_oVc803o`0002koi/b00_l0000konK<P003o`000?oVc83oi/b000?oi/b0
0002onK<P004o`000?oVc83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0
onK<P02>onK<P0Co0000;_oVc803o`0003goi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co
0000onK<P?oVc83o00001ooVc805o`0000Goi/b000?o0000onK<P?oVc800RooVc803o`00033oi/b0
0_l00010onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Co0000onK<P?oVc83o00001_oVc802o`0008Woi/b00ol0000bonK<P003o`000?oVc83oi/b003ko
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Ko
i/b000?o0000onK<P?oVc800QOoVc803o`0007Soi/b000?o0000onK<P?oVc8000ooVc80000;oi/b0
00Co0000onK<P?oVc83o00002OoVc802o`0000Koi/b000?o0000onK<P?oVc800P_oVc803o`0007_o
i/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l0000;onK<P003o`000?oVc83oi/b000Coi/b0
00?o0000onK<P?oVc800OooVc803o`0007koi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800O?oVc803o`00087oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800NOoVc803o`0008Coi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800M_oVc803o`0003Ooi/b00_l0001>onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b007;oi/b01?l0000gonK<P0?o0000D?oVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P01^onK<P0Co0000>OoVc802o`0005;oi/b00_l00005onK<P0005ooV
c8000ol0003oi/b0onK<P01[onK<P0?o0000>ooVc802o`0005Goi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800J?oVc803o`0003coi/b00_l0001GonK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b006Goi/b00ol0000nonK<P003o`000?oVc83oi/b0
05Ooi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800H_oVc803o`0009_o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800GooVc803o`0009koi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800G?oVc803o`000:7oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800F?oVc804o`000:Coi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800EOoVc803o`00047oi/b00_l0001TonK<
P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800DOoVc804o`0004;oi/b00_l0001WonK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b004koi/b00ol00014onK<P0;o0000
JOoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P01;onK<P0?o0000AOoV
c802o`0006_oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800AooVc804
o`0004Goi/b00ol0001]onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
04?oi/b01?l00017onK<P0;o0000L?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P00oonK<P0Co0000_OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P00lonK<P0?o0000`OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P00ionK<P0?o0000`ooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b003Ooi/b00_l00037
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b003Coi/b00ol0001:onK<
P0;o0000OOoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00aonK<P0?o
0000BooVc802o`0007ooi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
;OoVc804o`0004coi/b00_l00021onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oV
c8000ol0003oi/b0onK<P002onK<P0?o00001_oVc8000ol0003oi/b0onK<P00ZonK<P0?o0000COoV
c803o`0008?oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooV
c8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc8009_oVc804o`0004goi/b0
0ol00026onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b002;oi/b01?l0001@onK<P003
o`000?oVc83oi/b008Ooi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o
00001ooVc804o`0000Koi/b00_l0000PonK<P0?o0000g?oVc803o`0000Goi/b00002onK<P004o`00
0?oVc83oi/b0o`0000Ooi/b000?o0000onK<P?oVc8001ooVc8000ol0003oi/b0onK<P00KonK<P0Co
0000hOoVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P003
o`000?oVc83oi/b000Koi/b000?o0000onK<P?oVc8006?oVc803o`000>Goi/b000?o0000onK<P?oV
c8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0onK<P00EonK<P0?o0000
j?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00AonK<P0Co0000DooV
c803o`0009Goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc8003OoVc804
o`0005Coi/b00ol0002HonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
00Woi/b01?l0001EonK<P0?o0000VooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P005onK<P0Co0000E_oVc803o`0009koi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc8000_oVc803o`0005Woi/b000?o0000onK<P?oVc800W_oVc802o`0000Goi/b0
000GonK<P003o`000?oVc83o000000;o0000o_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc802
o`000?ooi/b00_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800o_oVc803o`0000Go
i/b0000GonK<P003o`000?oVc83oi/b0057oi/b00_l0002YonK<P005o`000?oVc83oi/b0onK<P?l0
00001OoVc80001Ooi/b000?o0000onK<P?oVc800CooVc802o`000:Woi/b00ol00003onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b004coi/b00ol0002XonK<P0;o00001ooV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P01:onK<P0;o0000ZOoVc802
o`0000Soi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P017onK<P0?o0000X_oVc802o`00
00;oi/b00ol0000=onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b004Go
i/b00_l0002OonK<P0?o00000_oVc8000ol0003oi/b0onK<P00BonK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00=Soi/b00_l000000ooVc83o0000o`000002o`000003onK<
P?l0003o000000;o00007?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P037onK<P0?o00000_oVc803o`0000;oi/b01?l000000ooVc83o0000o`00000XonK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:Woi/b00_l00002onK<P0?o00000_oVc804
o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002
o`0003_oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800>?oVc802o`00
04_oi/b00_l000000ooVc83o0000o`000002o`0000;oi/b00ol00002onK<P0?o00000_oVc804o`00
0003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P003o`000?oVc83oi/b0
05Goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800=_oVc802o`0000Ko
i/b000?o0000onK<P?oVc8003_oVc804o`0000;oi/b00ol00002onK<P0?o00000_oVc804o`000003
onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P0?o00000_oVc803o`0000;o
i/b00ol00002onK<P0Co000000?oi/b0o`000?l00000NooVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P002onK<P0?o00000_oVc803o`0000;oi/b01?l000000ooVc83o0000
o`000002o`000003onK<P?l0003o000000;o00000_oVc803o`0000;oi/b00ol00002onK<P0Co0000
00?oi/b0o`000?l000000_l000000ooVc83o0000o`000007o`0000;oi/b00ol00002onK<P0?o0000
0_oVc804o`000003onK<P?l0003o000000;o0000/OoVc802o`0000Goi/b0000GonK<P0?o0000<_oV
c802o`000<coi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800;ooVc803
o`000<koi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800;OoVc802o`00
0=7oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o0000
1_oVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co
0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Oo
i/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b0023oi/b00_l0003NonK<
P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Soi/b00ol00006onK<
P0;o00007ooVc802o`000=koi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<
P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P00LonK<P0;o0000h_oVc800
0ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P00IonK<P0?o0000i?oVc8000ol0003oi/b0onK<
P003onK<P0000ooVc802o`0000Woi/b00ol00006onK<P003o`000?oVc83oi/b001Koi/b00ol0003W
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b001Goi/b000?o0000onK<
P?oVc800j?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P008onK<P0;o0000mOoVc802o`0000Goi/b0000GonK<
P003o`000?oVc83oi/b000Koi/b00_l0003honK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b000?oi/b00ol0003jonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P004o`00
0?oVc83oi/b0onK<P0;o0000oOoVc8000ol0003oi/b0onK<P003onK<P0005ooVc804o`000?ooi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000>onK<P0?o00001_oVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000ooi/b000?o0000onK<
P?oVc8001OoVc8000ol0003oi/b0onK<P00`onK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<
P?oVc800<OoVc8000ol0003oi/b0onK<P00aonK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<
P?oVc8000ooVc80000ooi/b000?o0000onK<P?oVc8001OoVc8000ol0003oi/b0onK<P009onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003
o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8000ooVc80000ooi/b000?o0000onK<P?oVc800
1OoVc83oo`0000Go00001OoVc80000ooi/b000?o0000onK<P?oVc800oooVc80?onK<P0003_oVc802
o`000?ooi/b04OoVc80000ooi/b000?o0000onK<P?oVc800oooVc80?onK<P000oooVc80QonK<P000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheOnePopThreeStates[0, 1, 0.2, 0.5, 0.3, x, 5, 5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .54321 m
.04057 .5286 L
.08481 .51256 L
.12636 .49739 L
.16632 .48269 L
.20885 .46692 L
.2498 .4516 L
.29331 .43516 L
.33524 .41916 L
.37557 .40359 L
.41848 .38681 L
.4598 .37043 L
.49953 .35444 L
.54183 .33712 L
.58254 .32013 L
.62583 .30165 L
.66752 .28338 L
.70762 .26528 L
.7503 .24533 L
.79139 .22527 L
.83505 .20275 L
.87712 .17943 L
.9176 .15471 L
.96065 .12412 L
1 .08652 L
s
[ ] 0 setdash
0 .43457 m
.04057 .42288 L
.08481 .41005 L
.12636 .39791 L
.16632 .38615 L
.20885 .37353 L
.2498 .36128 L
.29331 .34813 L
.33524 .33533 L
.37557 .32287 L
.41848 .30945 L
.4598 .29634 L
.49953 .28355 L
.54183 .2697 L
.58254 .2561 L
.62583 .24132 L
.66752 .2267 L
.70762 .21222 L
.7503 .19626 L
.79139 .18022 L
.83505 .1622 L
.87712 .14354 L
.9176 .12377 L
.96065 .09929 L
1 .06922 L
s
[ .01 .01 .01 .01 ] 0 setdash
0 .49443 m
.01975 .49443 L
.02095 .49443 L
.02223 .49443 L
.02363 .49443 L
.02492 .49443 L
.02981 .49443 L
.03249 .49443 L
.03544 .49443 L
.03809 .49443 L
.03927 .49443 L
.04057 .49443 L
.0413 .49443 L
.04198 .49443 L
.04332 .49443 L
.04583 .49443 L
.0515 .49443 L
.06168 .49443 L
.08481 .49443 L
.10455 .49443 L
.10995 .49443 L
.11566 .49443 L
.1206 .49443 L
.12202 .49443 L
.12337 .49443 L
.12459 .49443 L
.12589 .49443 L
.12727 .49443 L
.12855 .49443 L
.12992 .49443 L
.1307 .49443 L
.13144 .49443 L
.13661 .49443 L
.13957 .49443 L
.14097 .49443 L
.14227 .49443 L
.14296 .49443 L
.14369 .49443 L
.14451 .49443 L
.14525 .49443 L
.14602 .49443 L
.14686 .49443 L
.14838 .49443 L
.15373 .49443 L
.15643 .49443 L
.1594 .49443 L
.16069 .49443 L
.16193 .49443 L
.16261 .49443 L
.16335 .49443 L
Mistroke
.16465 .49443 L
.16588 .49443 L
.16719 .49443 L
.16843 .49443 L
.16956 .49443 L
.18981 .49443 L
.20121 .49443 L
.21168 .49443 L
.2532 .49443 L
.29312 .49443 L
.31537 .49443 L
.33562 .49443 L
.35664 .49443 L
.37653 .49443 L
.39748 .49443 L
.41683 .49443 L
.43814 .49443 L
.45812 .49443 L
.47723 .49443 L
.49781 .49443 L
.51848 .49443 L
.54106 .49443 L
.55151 .49443 L
.55735 .49443 L
.56266 .49443 L
.56762 .49443 L
.57023 .49443 L
.57298 .49443 L
.5754 .49443 L
.57668 .49443 L
.57805 .49443 L
.57932 .49443 L
.58047 .49443 L
.58272 .49443 L
.58776 .49443 L
.59311 .49443 L
.60274 .49443 L
.62453 .49443 L
.66413 .49443 L
.70631 .49443 L
.7469 .49443 L
.79006 .49443 L
.83163 .49443 L
.87161 .49443 L
.89218 .49443 L
.8981 .49443 L
.89883 .49443 L
.89951 .49443 L
.90022 .49443 L
.90101 .49443 L
Mistroke
.9023 .49443 L
.90303 .49443 L
.90369 .49443 L
.90493 .49443 L
.90627 .49443 L
.90872 .49443 L
.91417 .49443 L
.95687 .49443 L
.99797 .49443 L
1 .49443 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l0
0005onK<P0005ooVc8000ol0003oi/b0onK<P03nonK<P003o`000?oVc83o000000Goi/b0000GonK<
P003o`000?oVc83oi/b00?goi/b000Co0000onK<P?oVc83o00001OoVc80001Ooi/b000?o0000onK<
P?oVc800o?oVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b0000GonK<P003o`000?oVc83oi/b0
0?[oi/b00_l00004onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?Wo
i/b000?o0000onK<P?oVc8000ooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?Soi/b0
00?o0000onK<P?oVc8001?oVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?Ooi/b000?o
0000onK<P?oVc8001_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03e
onK<P0;o00002OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03conK<
P0;o00002ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03aonK<P0;o
00003OoVc8000ol0003oi/b0onK<P003onK<P0000ooVc802o`0000Coi/b000Co0000onK<P?oVc83o
i/b01Ol00005onK<P003o`000?oVc83oi/b00>ooi/b00_l0000?onK<P003o`000?oVc83oi/b000?o
i/b00002onK<P004o`000?oVc83oi/b0o`0000Soi/b000Co0000onK<P?oVc83o00001OoVc8000ol0
003oi/b0onK<P03]onK<P0;o00004OoVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003o
i/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800jooVc802o`00
01?oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0
003oi/b0onK<P004onK<P0;o0000j_oVc802o`0000Woi/b00_l00008onK<P0?o00001OoVc80000;o
i/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000
onK<P?oVc800iooVc802o`0000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P003
onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoV
c8000ol0003oi/b0onK<P03UonK<P0;o00002ooVc8000ol0003oi/b0onK<P00;onK<P003o`000?oV
c83oi/b000?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800hooVc802
o`0000coi/b000?o0000onK<P?oVc8003?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03QonK<P0;o00003?oVc802o`0000ooi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800gooVc802o`0000goi/b000?o0000onK<P?oVc8003ooVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03MonK<P0;o00003_oVc8000ol0003oi/b0
onK<P00@onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00=[oi/b00ol0
000?onK<P003o`000?oVc83oi/b0017oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800f?oVc802o`00017oi/b000?o0000onK<P?oVc8004OoVc802o`0000Goi/b0000GonK<
P003o`000?oVc83oi/b00=Koi/b00_l0000XonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00=Coi/b00_l0000ZonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00=;oi/b00_l0000/onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00<ooi/b00ol0000^onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00<goi/b00_l0000aonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0<_oi/b00_l0000BonK<P0;o00007ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P039onK<P0;o00004_oVc802o`00027oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800a_oVc803o`0001;oi/b00_l0000RonK<P0;o00001OoVc80001Ooi/b000?o
0000onK<P?oVc800`ooVc803o`0001Coi/b000?o0000onK<P?oVc8008ooVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P030onK<P0?o00005OoVc802o`0002Koi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800__oVc802o`0001Koi/b00_l0000XonK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;_oi/b00ol0000GonK<P003
o`000?oVc83oi/b002Soi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
^?oVc803o`0001Woi/b000?o0000onK<P?oVc800:OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P02eonK<P0?o0000B?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P02conK<P0;o0000BooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P02`onK<P0?o0000C?oVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00:ko
i/b00_l0001@onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:_oi/b0
0ol0001BonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:Soi/b00ol0
000MonK<P0;o0000=_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P02T
onK<P0Co00007OoVc803o`0003Soi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004onK<
P003o`000?oVc83oi/b000?oi/b00ol00005onK<P003o`000?oVc83oi/b00:7oi/b00ol0000OonK<
P0;o0000>ooVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l0000:onK<
P003o`000?oVc83oi/b000Coi/b000?o0000onK<P?oVc800W_oVc803o`0001ooi/b00ol0000monK<
P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b01Ol00005onK<
P003o`000?oVc83oi/b009_oi/b00ol0000PonK<P0;o0000@?oVc8000ol0003oi/b0onK<P003onK<
P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P004o`000?oVc83oi/b0o`0000Koi/b00_l0002I
onK<P0?o00008_oVc8000ol0003oi/b0onK<P00nonK<P0?o00001OoVc80000;oi/b000Co0000onK<
P?oVc83o00002?oVc8000ol0003oi/b0o`000006onK<P003o`000?oVc83oi/b009Goi/b00ol0001X
onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Woi/b00_l00006
onK<P003o`000?oVc83oi/b009?oi/b00_l0001[onK<P003o`000?oVc83oi/b000?oi/b00003onK<
P0;o00002ooVc8000ol0003oi/b0onK<P004onK<P003o`000?oVc83oi/b0093oi/b00ol0001]onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b008goi/b00ol0001`onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b008[oi/b00ol0001conK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b008Ooi/b00ol0000VonK<P0;o0000C_oV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P023onK<P0Co00009_oVc803
o`00053oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800P?oVc803o`00
02Soi/b00_l0001BonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800OOoVc803o`0002Wo
i/b00_l0001EonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b007[oi/b0
0ol0000ZonK<P0;o0000EooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P01honK<P0;o0000;?oVc8000ol0003oi/b0onK<P01GonK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b007Goi/b00ol00028onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b007;oi/b00ol0002;onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b006koi/b01?l0002>onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b006_oi/b00ol0002BonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b006Ooi/b01?l0000^onK<P0;o0000I?oVc802o`0000Goi/b0000GonK<P003o`000?oVc83o
i/b006?oi/b01?l0000`onK<P0;o0000IooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P01PonK<P0?o0000<_oVc802o`0006Woi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800GOoVc803o`0003?oi/b00_l0001[onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b005[oi/b00ol0000conK<P0?o0000KOoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P01GonK<P0?o0000=?oVc802o`00073oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800E?oVc803o`000:Woi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800DOoVc803o`000:coi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800C_oVc803o`000:koi/b00_l00005onK<P000
5ooVc8000ol0003oi/b0onK<P01;onK<P0?o0000/_oVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P017onK<P0Co0000=_oVc802o`0007goi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800@ooVc804o`0003Soi/b00_l0001oonK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b003ooi/b01?l0000jonK<P0;o0000POoVc8000ol0
003oi/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803o`0000Ko
i/b000?o0000onK<P?oVc800??oVc803o`0003_oi/b00ol00023onK<P003o`000?oVc83oi/b000?o
i/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`000005onK<
P003o`000?oVc83oi/b003Woi/b00ol0000konK<P0?o0000Q_oVc8000ol0003oi/b0onK<P003onK<
P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc800
0ol0003oi/b0onK<P00gonK<P0;o0000?OoVc8000ol0003oi/b0onK<P027onK<P003o`000?oVc83o
i/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b01?l00006onK<P0;o0000=OoVc803
o`000<Ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P003o`000?oVc83o
i/b000Ooi/b000?o0000onK<P?oVc800<OoVc803o`000<coi/b000?o0000onK<P?oVc8000ooVc800
00;oi/b000Co0000onK<P?oVc83o00002?oVc8000ol0003oi/b0onK<P006onK<P003o`000?oVc83o
i/b002goi/b01?l0003?onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00002_oVc802o`00
00Koi/b000?o0000onK<P?oVc800:_oVc803o`000=?oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc8009_oVc804o`0003koi/b00ol0002EonK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b002;oi/b01?l0000oonK<P0?o0000V?oVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00OonK<P0?o0000@?oVc803o`0009_oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc8006ooVc804o`00043oi/b00ol0002N
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b001Soi/b00ol00013onK<
P003o`000?oVc83oi/b009koi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P00EonK<P0?o
0000j?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00AonK<P0Co0000
jooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00=onK<P0Co0000kooV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P009onK<P0Co0000looVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P005onK<P0Co0000B?oVc802o`00
0:goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc8000_oVc803o`0004[o
i/b00_l0002_onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o000000;o0000
B_oVc803o`000;7oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b00_l0001;onK<P0;o0000/ooV
c802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b004Ooi/b00ol0002fonK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b004Goi/b00_l0002ionK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b003Soi/b00_l00036onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
03Koi/b00_l00038onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b003Co
i/b00_l00039onK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800<_oVc802o`000<coi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800;ooVc803o`000<koi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800;OoVc802o`000=7oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o
00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b0023oi/b00_l0003NonK<P003o`000?oVc83o
i/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Soi/b00ol00006onK<P0;o00000_oVc803
o`0000;oi/b01?l000000ooVc83o0000o`000002o`000003onK<P?l0003o000000;o00000_oVc803
o`0000;oi/b02Ol000000ooVc83o0000o`000003o`0000;oi/b00ol00002onK<P0?o00000_oVc804
o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P0?o00000_oVc803
o`0000;oi/b01?l000000ooVc83o0000o`000002o`000003onK<P?l0003o000000;o00000_oVc803
o`0000;oi/b00ol00002onK<P0Co000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002
o`000003onK<P?l0003o000000;o00000_oVc803o`0000;oi/b00ol00002onK<P0Co000000?oi/b0
o`000?l000000_l000000ooVc83o0000o`000002o`0000;oi/b00ol00002onK<P0?o00000_oVc804
o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P0?o00000_oVc803
o`0000;oi/b00ol00002onK<P0Co000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002
o`0000;oi/b00ol00002onK<P0?o00000_oVc804o`000003onK<P?l0003o000000;o000000Coi/b0
o`000?l0003o00000_oVc804o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l0
0002onK<P0Ko00001OoVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<
P?oVc83o000000Goi/b000?o0000onK<P?oVc8007?oVc802o`000>;oi/b000?o0000onK<P?oVc800
0ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Go
i/b000?o0000onK<P?oVc8006OoVc803o`000>Coi/b000?o0000onK<P?oVc8000ooVc80000?oi/b0
0_l00009onK<P0?o00001_oVc8000ol0003oi/b0onK<P00FonK<P0?o0000iooVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P00EonK<P003o`000?oVc83oi/b00>Soi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc8002?oVc802o`000?Goi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P006onK<P0;o0000n?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P003
onK<P0?o0000n_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8001?l0003oi/b0onK<P?oVc802
o`000?goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b01?l0003oonK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0003_oVc803o`0000Koi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000?onK<P003o`000?oVc83oi/b000Goi/b000?o
0000onK<P?oVc800<?oVc8000ol0003oi/b0onK<P00aonK<P003o`000?oVc83oi/b0037oi/b000?o
0000onK<P?oVc800<OoVc8000ol0003oi/b0onK<P00aonK<P003o`000?oVc83oi/b000?oi/b0000?
onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc8002OoVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:
onK<P003o`000?oVc83oi/b000?oi/b0000?onK<P003o`000?oVc83oi/b000Goi/b0ool00005o`00
00Goi/b0000?onK<P003o`000?oVc83oi/b00?ooi/b03ooVc80000koi/b00_l0003oonK<P17oi/b0
000?onK<P003o`000?oVc83oi/b00?ooi/b03ooVc8000?ooi/b08OoVc8000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpomTwoPop", "Subsection"],

Cell["The parameter of the following", "Text"],

Cell["\<\
b: birth rate 
d: dispersal rate
e1: proba of extinction from pop 1
e2: proba of extinction from pop 2
n1: size of pop 1
n2: size of pop 2\
\>", "Text"],

Cell["[yinf,ysup,b,d,e1,e2,n1,n2]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[TwoSpomPoMatrix[1.1, 0.9999, 1, 0, 5, 5], 1]\)], "Input"],

Cell[BoxData[
    \({0.000549848777725348`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - Exp[\(-\((5\ 1.1)\)\)]\)], "Input"],

Cell[BoxData[
    \(0.995913228561536`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheTwoSpom[1.1, x, 0.5, 0, 5, 5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .49241 m
.00123 .4924 L
.00236 .4924 L
.00365 .49241 L
.00488 .49244 L
.00601 .49246 L
.00706 .4925 L
.00942 .49259 L
.01181 .49272 L
.01444 .49288 L
.01975 .49329 L
.04057 .49553 L
.08481 .50109 L
.12711 .50576 L
.16782 .50934 L
.21111 .51224 L
.23273 .51339 L
.2528 .51428 L
.27345 .51505 L
.2929 .51564 L
.31445 .51614 L
.33399 .51647 L
.34424 .5166 L
.34984 .51665 L
.35507 .5167 L
.35991 .51673 L
.36432 .51675 L
.36666 .51676 L
.36922 .51677 L
.37062 .51677 L
.37191 .51678 L
.37316 .51678 L
.37447 .51678 L
.37568 .51678 L
.37701 .51678 L
.37821 .51678 L
.37933 .51678 L
.38066 .51678 L
.38187 .51678 L
.38254 .51678 L
.38326 .51678 L
.38458 .51678 L
.38697 .51677 L
.38951 .51677 L
.39407 .51675 L
.39939 .51672 L
.40437 .51669 L
.4157 .51658 L
.42663 .51644 L
.437 .51627 L
Mistroke
.45646 .51586 L
.4773 .51528 L
.49662 .51461 L
.53776 .51271 L
.58148 .5099 L
.6236 .5063 L
.66413 .50184 L
.70724 .49581 L
.74876 .48845 L
.78869 .47958 L
.83119 .46767 L
.87209 .45296 L
.89294 .44381 L
.91558 .43215 L
.9355 .41988 L
.95747 .40314 L
.97811 .38229 L
.98941 .36703 L
1 .34818 L
Mfstroke
[ .01 .01 .01 .01 ] 0 setdash
0 .61551 m
.00942 .61539 L
.01975 .61529 L
.04057 .61514 L
.08481 .6149 L
.12734 .61466 L
.16829 .61437 L
.2118 .61398 L
.25373 .61349 L
.29406 .61288 L
.33697 .61206 L
.37829 .61107 L
.41802 .60987 L
.46032 .60826 L
.50103 .60633 L
.54432 .60376 L
.58601 .60065 L
.62611 .59693 L
.66879 .592 L
.70988 .58609 L
.75354 .57822 L
.79561 .56868 L
.83609 .55711 L
.87914 .54125 L
.90058 .53143 L
.9206 .52065 L
.94146 .50709 L
.96047 .49162 L
.9702 .48197 L
.98077 .46939 L
.99076 .45437 L
1 .43523 L
s
[ ] 0 setdash
0 .49443 m
.00123 .49443 L
.00236 .49445 L
.00365 .49447 L
.00488 .49451 L
.00706 .49459 L
.00942 .49471 L
.01479 .49506 L
.01975 .49549 L
.04057 .49786 L
.08481 .50364 L
.12613 .50843 L
.16585 .5122 L
.20816 .51542 L
.24887 .51788 L
.29215 .51993 L
.33385 .52145 L
.37395 .52257 L
.39633 .52307 L
.41663 .52345 L
.43802 .52378 L
.45771 .52402 L
.47792 .52421 L
.48855 .52429 L
.49978 .52436 L
.50973 .5244 L
.51531 .52442 L
.5204 .52444 L
.52514 .52445 L
.52781 .52445 L
.53029 .52445 L
.53245 .52446 L
.53367 .52446 L
.53483 .52446 L
.53604 .52446 L
.53715 .52446 L
.53837 .52446 L
.53965 .52446 L
.54095 .52446 L
.54168 .52446 L
.54235 .52446 L
.54359 .52446 L
.5449 .52446 L
.54718 .52445 L
.54967 .52445 L
.55521 .52444 L
.56038 .52443 L
.56968 .5244 L
.57967 .52435 L
.5903 .52428 L
Mistroke
.6019 .52419 L
.62301 .52399 L
.6437 .52372 L
.66574 .52336 L
.70946 .5224 L
.75158 .52112 L
.79211 .51947 L
.83522 .51713 L
.87674 .51407 L
.91666 .51003 L
.93719 .50733 L
.95916 .50372 L
1 .49443 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004
onK<P004o`000?oVc83oi/b0onK<P0Go00001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<
P?l00005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000[oi/b0
00?o0000onK<P?oVc8001?oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<
P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003o
i/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc805o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00001_oVc802o`000?ooi/b00ol00005onK<P000
0_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Koi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Wo
i/b00_l00006onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
0ooVc802o`0000_oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0
0003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oVc8000ol0003oi/b0onK<
P03nonK<P003o`000?oVc83o000000Goi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go
0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?koi/b000?o0000onK<P?l00000
1OoVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Go
i/b000?o0000onK<P?oVc800oOoVc8001?l0003oi/b0onK<P?l00005onK<P0000_oVc8001?l0003o
i/b0onK<P?l00007onK<P0Co00001_oVc802o`000?koi/b01?l00005onK<P0000_oVc8001?l0003o
i/b0onK<P?l00007onK<P003o`000?oVc83oi/b000Ooi/b000?o0000onK<P?oVc800o?oVc8001Ol0
003oi/b0onK<P?oVc83o000000Goi/b00002onK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000
onK<P?oVc8001_oVc8000ol0003oi/b0onK<P03konK<P003o`000?oVc83oi/b000;oi/b000?o0000
onK<P?oVc8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0onK<P03jonK<
P003o`000?oVc83oi/b000?oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800nOoVc8000ol0003oi/b0onK<P004onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?Soi/b000?o0000onK<P?oVc8001OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800k_oVc802o`00013oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800k?oVc802o`0001;oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
jooVc8000ol0003oi/b0onK<P00BonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00>Woi/b00_l0000DonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800iooVc802
o`0001Koi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03UonK<P0;o00006?oVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00>?oi/b00_l0000IonK<P003o`000?oVc83o000000Go
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800oOoVc8001?l0003oi/b0onK<P?l00005onK<P0005ooVc8000ol0003oi/b0onK<P03m
onK<P004o`000?oVc83oi/b0o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00=Koi/b00_l0000T
onK<P003o`000?oVc83oi/b000;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800dooVc803o`00
02[oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800d?oVc803o`0002Oo
i/b000?o0000onK<P?oVc8000ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03=onK<P0?o0000:_oVc8000ol0003oi/b0onK<P003onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00<_oi/b00_l0000/onK<P003o`000?oVc83oi/b000Coi/b000?o
0000onK<P?oVc8000ooVc80000?oi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol00006
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0
003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<
P03fonK<P0;o00002?oVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l0
0007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc804o`000;Soi/b01_l0000fonK<P003o`00
0?oVc83oi/b000Soi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o0000
2?oVc803o`0000Koi/b02Ol0002]onK<P0Ko0000??oVc8000ol0003oi/b0onK<P005onK<P0Co0000
1OoVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Go
i/b000?o0000onK<P?oVc8001_oVc80;o`000:3oi/b00_l00010onK<P003o`000?oVc83oi/b000;o
i/b01Ol00003onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Oo
i/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b000koi/b03?l00028onK<
P0Co0000C?oVc806o`0000Soi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00009onK<P0?o
00001_oVc8000ol0003oi/b0onK<P00GonK<P0Go0000OooVc807o`0004_oi/b01Ol0000>onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b001coi/b02?l00002onK<P0Wo0000
JOoVc803o`0004[oi/b02?l00002onK<P003o`000?oVc83oi/b000koi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc8009?oVc80Eo`0000Ooi/b03?l0000bonK<P0ko0000CooV
c80:o`0000Woi/b000?o0000onK<P?oVc8003ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P00ionK<P0_o00002?oVc802o`0000coi/b03_l00006onK<P0Co0000DooVc80F
o`0001;oi/b000?o0000onK<P?oVc8004?oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P014onK<P2Wo0000>OoVc80Oo`0002Coi/b00_l0000EonK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b006goi/b0>Ol00012onK<P003o`000?oVc83oi/b001Co
i/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc800iOoVc802o`0001Woi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800i?oVc8000ol0003oi/b0onK<P00IonK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00>3oi/b00_l0000NonK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00=ooi/b000?o0000onK<P?oVc8007_oVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03KonK<P0;o00008ooVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03FonK<P0;o00000_oVc8000ol0003oi/b0onK<
P00SonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00=Goi/b000?o0000
onK<P?oVc8009ooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00=;oi/b00_l0000/onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00<goi/b00_l000000ooVc83o
0000o`00000^onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00<_oi/b0
0_l0000conK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00<Koi/b01?l0
000fonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00<7oi/b00ol0000l
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;coi/b00ol00011onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;Ooi/b00ol00016onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00;;oi/b00ol0001:onK<P0;o0000
1OoVc80001Ooi/b000?o0000onK<P?oVc800ZOoVc802o`0000;oi/b00ol0001@onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00:3oi/b000?o0000onK<P?l000000ol00000
0ooVc83o0000o`00001GonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
09Coi/b00_l00002onK<P0Co000000Coi/b0o`000?l0003o0000H?oVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P028onK<P0Co00000_oVc803o`0000;oi/b000?o0000onK<
P?oVc800J_oVc8000ol0003oi/b0onK<P003onK<P0003_oVc803o`0000Koi/b000?o0000onK<P?oV
c800M?oVc803o`0000;oi/b00ol00002onK<P0Co000000?oi/b0o`000?l000000_l0001ionK<P003
o`000?oVc83oi/b000?oi/b0000?onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
<?oVc8000ol0003oi/b0onK<P00RonK<P0?o00000_oVc803o`0000;oi/b01?l000000ooVc83o0000
o`000002o`000003onK<P?l0003o000000;o00000_oVc803o`0000;oi/b000?o0000onK<P?oVc800
8OoVc8000ol0003oi/b0onK<P00aonK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<P?oVc800
0ooVc80000ooi/b000?o0000onK<P?oVc8001OoVc803o`0000;oi/b00ol00002onK<P0?o00000_oV
c804o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P0?o00000_oV
c803o`0000;oi/b01?l000000ooVc83o0000o`000002o`000003onK<P?l0003o000000;o00000_oV
c803o`0000;oi/b00ol00002onK<P0?o00000_oVc804o`000003onK<P?l0003o000000;o000000?o
i/b0o`000?l000000_l00004onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oV
c8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oV
c8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oV
c8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oV
c8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8000ooV
c80000ooi/b000?o0000onK<P?oVc8001OoVc83oo`0000Go00001OoVc80000ooi/b000?o0000onK<
P?oVc800oooVc80?onK<P0003_oVc802o`000?ooi/b04OoVc80000ooi/b000?o0000onK<P?oVc800
oooVc80?onK<P000oooVc80QonK<P000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheTwoSpom[1.1, x, 0.2, 0, 5, 5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .49241 m
.00942 .50073 L
.01975 .50736 L
.03053 .51241 L
.04057 .51607 L
.06194 .52181 L
.07392 .52422 L
.08481 .52607 L
.10661 .52906 L
.12674 .5312 L
.16707 .53434 L
.18673 .53547 L
.20839 .53651 L
.23048 .53738 L
.25069 .53805 L
.2914 .53908 L
.31134 .53946 L
.33309 .5398 L
.35375 .54006 L
.37577 .54027 L
.38657 .54035 L
.39825 .54042 L
.40929 .54047 L
.41943 .54051 L
.42437 .54052 L
.42966 .54053 L
.43222 .54053 L
.43465 .54054 L
.43683 .54054 L
.4392 .54054 L
.44054 .54054 L
.4418 .54054 L
.44318 .54054 L
.44395 .54054 L
.44466 .54054 L
.44601 .54054 L
.44678 .54054 L
.44749 .54054 L
.44825 .54054 L
.44893 .54054 L
.45047 .54054 L
.45181 .54054 L
.45304 .54054 L
.45583 .54054 L
.4609 .54053 L
.4658 .54052 L
.47107 .5405 L
.4806 .54047 L
.49192 .54042 L
.50227 .54036 L
Mistroke
.52224 .54021 L
.54402 .53999 L
.56644 .5397 L
.58675 .53939 L
.62789 .53855 L
.67002 .53739 L
.71055 .5359 L
.75366 .5338 L
.79517 .53108 L
.8351 .52754 L
.85734 .52501 L
.8776 .52222 L
.89886 .51863 L
.91851 .51449 L
.93859 .50907 L
.9604 .5011 L
1 .49039 L
Mfstroke
[ .01 .01 .01 .01 ] 0 setdash
0 .61551 m
.04057 .61581 L
.06168 .616 L
.08481 .61616 L
.10632 .61627 L
.12636 .61634 L
.13738 .61637 L
.1478 .61639 L
.15708 .61641 L
.1673 .61643 L
.17748 .61644 L
.18268 .61644 L
.18827 .61645 L
.1935 .61645 L
.19827 .61645 L
.20057 .61645 L
.20307 .61645 L
.20545 .61646 L
.20764 .61646 L
.20894 .61646 L
.21032 .61646 L
.2117 .61646 L
.21248 .61646 L
.21322 .61646 L
.21454 .61646 L
.21575 .61646 L
.21642 .61646 L
.21715 .61646 L
.21847 .61646 L
.21965 .61646 L
.22094 .61646 L
.22357 .61645 L
.22601 .61645 L
.22829 .61645 L
.23382 .61645 L
.23889 .61645 L
.25031 .61644 L
.26061 .61643 L
.27018 .61642 L
.29192 .61638 L
.3134 .61634 L
.33292 .61629 L
.3749 .61615 L
.41529 .61598 L
.45825 .61573 L
.49963 .61542 L
.53941 .61504 L
.58176 .61453 L
.62253 .61391 L
.66587 .61307 L
Mistroke
.70762 .61203 L
.74778 .61075 L
.79051 .60896 L
.83165 .60663 L
.85417 .60498 L
.87537 .60308 L
.8947 .60093 L
.9159 .59792 L
.93688 .59387 L
.94833 .59095 L
.95901 .58752 L
.97001 .58288 L
.97542 .57999 L
.98042 .57677 L
.98486 .57331 L
.98976 .56851 L
.99469 .56196 L
.99739 .55706 L
.99992 .55078 L
1 .55053 L
Mfstroke
[ ] 0 setdash
0 .49443 m
.00942 .50281 L
.01975 .50939 L
.03053 .51436 L
.04057 .51794 L
.06194 .52352 L
.07392 .52587 L
.08481 .52767 L
.10661 .53058 L
.12674 .53266 L
.16707 .53573 L
.18673 .53685 L
.20839 .53788 L
.25069 .53944 L
.2914 .54052 L
.33469 .54136 L
.35631 .54168 L
.37638 .54193 L
.41648 .54231 L
.43803 .54245 L
.45757 .54255 L
.4674 .54259 L
.47778 .54263 L
.48321 .54264 L
.48916 .54266 L
.49418 .54267 L
.49964 .54267 L
.5025 .54268 L
.50514 .54268 L
.50762 .54268 L
.51035 .54268 L
.51153 .54269 L
.5128 .54269 L
.51389 .54269 L
.51509 .54269 L
.51637 .54269 L
.51772 .54269 L
.51896 .54269 L
.52012 .54269 L
.5215 .54269 L
.52227 .54269 L
.52299 .54269 L
.5243 .54269 L
.52569 .54269 L
.52809 .54268 L
.53074 .54268 L
.5366 .54268 L
.54208 .54267 L
.55301 .54265 L
.56339 .54262 L
Mistroke
.58285 .54254 L
.60369 .54243 L
.62301 .54229 L
.66415 .54189 L
.68667 .5416 L
.70786 .54128 L
.7484 .54048 L
.79151 .53931 L
.83302 .53775 L
.87295 .53566 L
.89347 .53427 L
.91545 .53246 L
.93629 .53038 L
.94728 .52914 L
.95893 .52776 L
.96382 .52721 L
.96908 .52668 L
.97055 .52655 L
.9721 .52644 L
.97353 .52635 L
.97486 .52629 L
.97611 .52626 L
.97745 .52625 L
.97821 .52625 L
.97893 .52628 L
.98028 .52635 L
.98142 .52646 L
.98267 .52663 L
.98398 .52689 L
.98521 .52722 L
.98635 .52762 L
.9874 .52809 L
.98975 .52955 L
.99106 .5307 L
.99227 .53203 L
.99357 .5338 L
.99501 .53625 L
.99743 .54183 L
.99875 .54587 L
1 .55053 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004
onK<P004o`000?oVc83oi/b0onK<P0Go00001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<
P?l00005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000[oi/b0
00?o0000onK<P?oVc8001?oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<
P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003o
i/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc805o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00001_oVc802o`000?ooi/b00ol00005onK<P000
0_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Koi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Wo
i/b00_l00006onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
0ooVc802o`0000_oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000
onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P0Co00001_oVc802o`000?oo
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P003o`000?oVc83oi/b000Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`00
0?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8001_oVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<
P002onK<P0?o00001_oVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ko
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P0?o00001_oVc802o`000?go
i/b01Ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<
P?l000001OoVc802o`000?ooi/b00_oVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0o`000002
o`000?koi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00009onK<P0?o00001_oVc8001?l0
003oi/b0onK<P?oVc802o`000?goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc8000_oVc802o`000>[oi/b00ol0000?onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b000Coi/b00ol0003RonK<P0Go00004_oVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P007onK<P0Co0000f_oVc804o`0001Ooi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc8002ooVc805o`000=?oi/b00_l0000KonK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0013oi/b01ol0002oonK<P003o`000?oVc83o
i/b001goi/b01ol00002onK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc8004ooVc80;o`00
0:goi/b02ol0000GonK<P0Wo00001_oVc802o`0000;oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc8007?oVc808o`0009Goi/b01Ol0000<onK<P003o`000?oVc83oi/b001Go
i/b02ol0000AonK<P003o`000?oVc83o000000Goi/b0000GonK<P003o`000?oVc83oi/b002Coi/b0
5_l0000;onK<P0?o0000DooVc809o`0000coi/b02Ol0000FonK<P1?o00007?oVc8000ol0003oi/b0
o`000005onK<P0005ooVc8000ol0003oi/b0onK<P00ionK<P9Ko0000<?oVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P03nonK<P003o`000?oVc83o000000Goi/b0000GonK<P003o`000?oVc83oi/b00?koi/b000?o0000
onK<P?l000001OoVc80001Ooi/b000?o0000onK<P?oVc800oOoVc8001?l0003oi/b0onK<P?l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800nooVc802o`0000?oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800n_oVc8000ol0003oi/b0onK<P003onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?Koi/b00_l00008onK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b00?Goi/b000?o0000onK<P?oVc8001ooVc802o`0000Goi/b0000GonK<
P003o`000?oVc83oi/b00?7oi/b00_l0000=onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00>coi/b00_l00002onK<P003o`000?oVc83oi/b000goi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800i_oVc803o`0000;oi/b000?o0000onK<P?oVc800
4_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03KonK<P0Co00000_oV
c803o`0001coi/b000?o0000onK<P?oVc8000ooVc80000koi/b00ol00006onK<P003o`000?oVc83o
i/b00<goi/b00_l00002onK<P0Co000000?oi/b0o`000?l000000_l0000VonK<P003o`000?oVc83o
i/b000?oi/b0000?onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800<?oVc8000ol0
003oi/b0onK<P00aonK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<P?oVc8006?oVc803o`00
0003onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002o`00
00;oi/b00ol00002onK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<P?oVc8000ooVc80000oo
i/b000?o0000onK<P?oVc8001OoVc802o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l0
00000ol000001?oVc83o0000o`000?l00008onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<
P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<
P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P004o`000?oVc83oi/b0onK<P0?o00000_oVc809
o`000003onK<P?l0003o000000;o00000_oVc803o`0000;oi/b00ol00002onK<P0Wo000000?oi/b0
o`000?l000000_l00002onK<P0?o00000_oVc803o`0000;oi/b00ol000000ooVc83o0000o`000004
o`0000;oi/b00ol00002onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc800
0ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc8002_oVc800
0ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000?oi/b0000?onK<P003o`000?oVc83oi/b0
00Goi/b0ool00005o`0000Goi/b0000?onK<P003o`000?oVc83oi/b00?ooi/b03ooVc80000koi/b0
0_l0003oonK<P17oi/b0000?onK<P003o`000?oVc83oi/b00?ooi/b03ooVc8000?ooi/b08OoVc800
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpomThreePop", "Subsection"],

Cell["\<\
b: birth rate 
d: dispersal rate
e1: proba of extinction from pop 1
e2: proba of extinction from pop 2
e3: proba of extinction from pop 3
n1: size of pop 1
n2: size of pop 2
n3: size of pop 3
d\[CapitalLambda]13: proba of migration from pop 3 to pop1
d\[CapitalLambda]12: proba of migration from pop 2 to pop1
d\[CapitalLambda]21: proba of migration from pop 1 to pop2\
\>", "Text"],

Cell["[yinf,ysup,b,d,e1,e2,e3,n1,n2,n3]", "Text"],

Cell[BoxData[
    \(\([b, d, e1, e2, e3, n1, n2, 
      n3, \[CapitalLambda]13, \[CapitalLambda]12, \[CapitalLambda]21]\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[
      ThreeSpomPoMatrix[1.1, 0.9, 0.5, 0.5, 0, 5, 5, 5, 0.5, 0.5, 0.5], 
      1]\)], "Input"],

Cell[BoxData[
    \({0.9492685044450802`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheThreeSpom[0, 1, 1.1, x, 0, 0, 0, 5, 5, 5, 0.5, 0.5, 
      0.5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .61299 m
.01975 .6054 L
.04057 .59838 L
.0515 .59562 L
.06168 .59348 L
.08481 .58973 L
.10625 .58722 L
.12575 .58548 L
.14755 .58395 L
.16768 .58283 L
.20801 .58114 L
.22767 .58051 L
.24933 .57992 L
.29163 .57902 L
.33234 .57836 L
.37563 .57784 L
.41732 .57745 L
.45743 .57716 L
.5001 .57693 L
.54119 .57676 L
.56367 .57669 L
.58485 .57664 L
.60593 .5766 L
.62533 .57658 L
.63555 .57657 L
.64509 .57656 L
.65057 .57656 L
.65557 .57656 L
.65833 .57656 L
.65989 .57656 L
.66133 .57656 L
.66259 .57656 L
.66331 .57656 L
.66398 .57656 L
.66468 .57656 L
.66543 .57656 L
.66679 .57656 L
.66813 .57656 L
.6694 .57656 L
.67054 .57656 L
.67177 .57656 L
.67311 .57656 L
.67453 .57656 L
.67708 .57656 L
.68164 .57656 L
.68666 .57656 L
.69207 .57657 L
.69789 .57657 L
.7084 .57658 L
.71903 .57659 L
Mistroke
.73063 .57661 L
.75174 .57665 L
.77243 .5767 L
.79447 .57677 L
.83819 .57695 L
.88031 .57719 L
.92084 .57749 L
.96395 .57792 L
1 .57837 L
Mfstroke
[ .01 .01 .01 .01 ] 0 setdash
0 .61551 m
.00123 .61715 L
.00236 .61754 L
.00365 .61774 L
.00488 .61784 L
.00601 .61789 L
.00706 .61792 L
.00821 .61794 L
.00942 .61796 L
.01065 .61797 L
.01196 .61798 L
.0132 .61799 L
.01434 .618 L
.01566 .618 L
.01711 .61801 L
.01975 .61801 L
.02116 .61801 L
.02249 .61802 L
.02497 .61802 L
.02765 .61802 L
.03054 .61802 L
.03308 .61802 L
.03576 .61803 L
.04057 .61803 L
.04583 .61803 L
.05147 .61803 L
.0568 .61803 L
.06166 .61803 L
.06735 .61803 L
.07355 .61803 L
.08481 .61803 L
.09468 .61803 L
.10557 .61803 L
.11695 .61803 L
.12763 .61803 L
.13795 .61803 L
.14882 .61803 L
.16825 .61803 L
.18898 .61803 L
.20827 .61803 L
.22975 .61803 L
.24926 .61803 L
.27111 .61803 L
.29124 .61803 L
.33163 .61803 L
.37301 .61803 L
.41279 .61803 L
.45515 .61803 L
.49591 .61803 L
.51665 .61803 L
Mistroke
.53925 .61803 L
.56116 .61803 L
.581 .61803 L
.6017 .61803 L
.61318 .61803 L
.62373 .61803 L
.63359 .61803 L
.64398 .61803 L
.64938 .61803 L
.65442 .61803 L
.65731 .61803 L
.65994 .61803 L
.6614 .61803 L
.66217 .61803 L
.66298 .61803 L
.66369 .61803 L
.66448 .61803 L
.66586 .61803 L
.66714 .61803 L
.66833 .61803 L
.66964 .61803 L
.67037 .61803 L
.67104 .61803 L
.67238 .61803 L
.67384 .61803 L
.67648 .61803 L
.67894 .61803 L
.68155 .61803 L
.68621 .61803 L
.69161 .61803 L
.69665 .61803 L
.70813 .61803 L
.71908 .61803 L
.72947 .61803 L
.74895 .61803 L
.76982 .61803 L
.78916 .61803 L
.83035 .61803 L
.86996 .61803 L
.91214 .61803 L
.95272 .61803 L
.99589 .61803 L
1 .61803 L
Mfstroke
[ ] 0 setdash
0 .61551 m
.00942 .61003 L
.01975 .60542 L
.04057 .59839 L
.05163 .5956 L
.06347 .59314 L
.08481 .58973 L
.10718 .58713 L
.12833 .58528 L
.16866 .58278 L
.18949 .58184 L
.21157 .58102 L
.2513 .57987 L
.2936 .57898 L
.33431 .57834 L
.3776 .57782 L
.41929 .57743 L
.45939 .57715 L
.50207 .57692 L
.54316 .57676 L
.56564 .57669 L
.58682 .57664 L
.59707 .57662 L
.6079 .5766 L
.61805 .57659 L
.6273 .57658 L
.63725 .57657 L
.64273 .57657 L
.64792 .57656 L
.65271 .57656 L
.65714 .57656 L
.65945 .57656 L
.66078 .57656 L
.662 .57656 L
.66328 .57656 L
.66466 .57656 L
.66588 .57656 L
.66717 .57656 L
.66846 .57656 L
.66919 .57656 L
.66987 .57656 L
.67111 .57656 L
.67242 .57656 L
.67469 .57656 L
.67719 .57656 L
.67986 .57656 L
.68272 .57656 L
.6879 .57656 L
.69797 .57657 L
.70718 .57658 L
Mistroke
.72715 .57661 L
.73845 .57662 L
.74893 .57664 L
.79007 .57676 L
.81259 .57684 L
.83379 .57693 L
.87432 .57715 L
.91743 .57747 L
.95894 .57786 L
.99887 .57836 L
1 .57837 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004
onK<P004o`000?oVc83oi/b0onK<P0Go00001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<
P?l00005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000[oi/b0
00?o0000onK<P?oVc8001?oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<
P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003o
i/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc805o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00001_oVc802o`000?ooi/b00ol00005onK<P000
0_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Koi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Wo
i/b00_l00006onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
0ooVc802o`0000_oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000
onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P0Co00001_oVc802o`000?oo
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P003o`000?oVc83oi/b000Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`00
0?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8001_oVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<
P002onK<P0?o00001_oVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P0?o
00001_oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o
000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<
P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800I?oVc82=o`0000ooi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800;_oVc80fo`0008coi/b04Ol00005
onK<P0005ooVc8000ol0003oi/b0onK<P00SonK<P0ko0000cooVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P00FonK<P0go0000g?oVc802o`0000Goi/b0000GonK<P003o`00
0?oVc83oi/b0013oi/b01_l0003ZonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b000Woi/b01ol0003`onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b000Koi/b00ol0003gonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
00?oi/b00ol0003jonK<P003o`000?oVc83oi/b000?oi/b0000>onK<P0?o00001_oVc8001?l0003o
i/b0onK<P?oVc802o`000?goi/b000?o0000onK<P?oVc8000ooVc80000ooi/b000?o0000onK<P?oV
c8001OoVc804o`0002ooi/b000?o0000onK<P?oVc800<OoVc8000ol0003oi/b0onK<P00aonK<P003
o`000?oVc83oi/b0037oi/b000?o0000onK<P?oVc800<OoVc8000ol0003oi/b0onK<P003onK<P000
3ooVc8000ol0003oi/b0onK<P005onK<P003o`000?oVc83oi/b000Woi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oVc800
2_oVc8000ol0003oi/b0onK<P003onK<P0003ooVc8000ol0003oi/b0onK<P005onK<P?oo00001Ol0
0005onK<P0003ooVc8000ol0003oi/b0onK<P03oonK<P0ooi/b0000>onK<P0;o0000oooVc80AonK<
P0003ooVc8000ol0003oi/b0onK<P03oonK<P0ooi/b0003oonK<P27oi/b00000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheThreeSpom[0, 1, 1.1, x, 0.5, 0.5, 0, 5, 5, 5, 0.5, 0.5, 
      0.5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .05 ] 0 setdash
0 .49241 m
.00123 .4924 L
.00236 .49239 L
.00365 .49239 L
.00488 .4924 L
.00601 .49241 L
.00706 .49242 L
.00821 .49244 L
.00942 .49247 L
.01196 .49254 L
.01434 .49262 L
.01975 .4929 L
.02499 .49325 L
.02978 .49365 L
.04057 .49476 L
.08481 .50125 L
.1265 .50803 L
.16661 .51393 L
.20928 .51922 L
.25037 .52337 L
.29403 .52691 L
.3361 .52958 L
.37658 .53156 L
.3971 .53237 L
.41963 .53312 L
.44132 .53371 L
.46109 .53415 L
.48158 .53449 L
.49286 .53463 L
.50354 .53473 L
.51368 .53481 L
.51879 .53483 L
.52174 .53485 L
.52444 .53486 L
.52674 .53486 L
.52924 .53487 L
.53177 .53487 L
.53314 .53487 L
.53442 .53488 L
.53564 .53488 L
.53679 .53488 L
.53783 .53488 L
.53895 .53488 L
.54017 .53488 L
.54146 .53487 L
.54257 .53487 L
.54379 .53487 L
.5464 .53487 L
.54926 .53486 L
.55446 .53484 L
Mistroke
.55951 .53482 L
.56421 .53479 L
.57483 .5347 L
.58614 .53457 L
.60867 .53422 L
.62986 .53376 L
.65098 .53317 L
.67039 .5325 L
.71191 .53063 L
.75183 .52821 L
.79433 .5248 L
.83524 .52054 L
.87873 .51465 L
.92062 .50721 L
.96092 .49771 L
1 .48509 L
Mfstroke
[ .01 .01 .01 .01 ] 0 setdash
0 .61551 m
.01975 .61526 L
.04057 .61507 L
.06168 .61492 L
.08481 .6148 L
.12734 .61464 L
.16829 .6145 L
.2118 .61432 L
.25373 .61411 L
.29406 .61385 L
.33697 .6135 L
.37829 .61307 L
.41802 .61257 L
.46032 .61191 L
.50103 .61114 L
.54432 .61014 L
.58601 .60897 L
.62611 .60761 L
.66879 .60585 L
.70988 .60379 L
.75354 .60113 L
.79561 .59799 L
.83609 .5943 L
.87914 .58946 L
.9206 .5836 L
.96047 .57644 L
1 .5671 L
s
[ ] 0 setdash
0 .49443 m
.00123 .49443 L
.00236 .49444 L
.00365 .49445 L
.00488 .49447 L
.00706 .49452 L
.00942 .49459 L
.01203 .49469 L
.01479 .49482 L
.01975 .49512 L
.02966 .49594 L
.04057 .49714 L
.08481 .50389 L
.12711 .51093 L
.16782 .51705 L
.21111 .52255 L
.2528 .52693 L
.2929 .53041 L
.33558 .53345 L
.37667 .53585 L
.42033 .53793 L
.4624 .53954 L
.50288 .54079 L
.54593 .54182 L
.56737 .54223 L
.58739 .54255 L
.60787 .54282 L
.62726 .54302 L
.6375 .54311 L
.64863 .54318 L
.65875 .54323 L
.66812 .54327 L
.67298 .54328 L
.67553 .54328 L
.67822 .54329 L
.68059 .54329 L
.68184 .54329 L
.68317 .54329 L
.68441 .5433 L
.68553 .5433 L
.68665 .5433 L
.68771 .5433 L
.68896 .5433 L
.69034 .5433 L
.69103 .5433 L
.69177 .5433 L
.69311 .54329 L
.69445 .54329 L
.69572 .54329 L
.69809 .54329 L
Mistroke
.70089 .54328 L
.70348 .54328 L
.70935 .54326 L
.71469 .54324 L
.72047 .54321 L
.73094 .54314 L
.74113 .54306 L
.75049 .54297 L
.77029 .54272 L
.792 .54234 L
.81253 .54189 L
.8345 .54127 L
.85535 .54055 L
.87799 .53959 L
.91988 .53719 L
.94068 .5356 L
.96276 .53352 L
1 .52866 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004
onK<P004o`000?oVc83oi/b0onK<P0Go00001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<
P?l00005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000[oi/b0
00?o0000onK<P?oVc8001?oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<
P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003o
i/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc805o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00001_oVc802o`000?ooi/b00ol00005onK<P000
0_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Koi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Wo
i/b00_l00006onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
0ooVc802o`0000_oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000
onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P0Co00001_oVc802o`000?oo
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P003o`000?oVc83oi/b000Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`00
0?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8001_oVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<
P002onK<P0?o00001_oVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b0
00?o0000onK<P?oVc800o_oVc803o`0000Goi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P0?o00001_oVc80:o`000003
onK<P?l0003o000000;o0000l_oVc803o`0000Goi/b00002onK<P004o`000?oVc83oi/b0o`0000Oo
i/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b000Ooi/b02_l0003_onK<
P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b000koi/b02Ol0003HonK<P0Co00003OoVc800
0ol0003oi/b0onK<P003onK<P0000ooVc802o`0000Woi/b00ol00006onK<P003o`000?oVc83oi/b0
01Ooi/b01Ol0003<onK<P0Oo00004OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P00LonK<P0[o0000_ooVc803o`0001Soi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc8008OoVc80;o`000=Coi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc8009_oVc809o`000:Soi/b00_l0000WonK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b002ooi/b02ol000000ooVc83o0000o`000007o`0008coi/b01ol0000Y
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b003[oi/b03ol00022onK<
P0Go0000;ooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b004Coi/b02ol00006onK<P0Ko
0000F?oVc80<o`0003coi/b01_l00005onK<P0005ooVc8000ol0003oi/b0onK<P01?onK<P0_o0000
00?oi/b0o`000?l000001_l0000<onK<P0ko00003?oVc804o`0000[oi/b03_l0000<onK<P0;o0000
@?oVc808o`0000Goi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800F_oV
c80Fo`0007Koi/b03Ol0000=onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b0073oi/b0:Ol0000YonK<P2Co00006_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P02IonK<P2Wo0000?_oVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l0
0005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03jonK<P0?o0000
0ooVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03eonK<P0?o00002?oV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03`onK<P0?o00003OoVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03[onK<P0?o00004_oVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03RonK<P0;o00000_oVc803o`0001Ko
i/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03HonK<P0;o000000?oi/b0o`000?l00000
0_l000000ooVc83o0000o`00000NonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00<goi/b00_l00002onK<P0Co000000?oi/b0o`000?l00000:?oVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P033onK<P0;o00000_oVc803o`0000;oi/b000?o0000
onK<P?oVc800<OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P02bonK<
P0?o00000_oVc804o`000003onK<P?l0003o000000;o000000?oi/b0o`000?l00000?OoVc8000ol0
003oi/b0onK<P003onK<P0003_oVc803o`0000Koi/b000?o0000onK<P?oVc800V_oVc802o`000003
onK<P?l0003o000000;o000000?oi/b0o`000?l000000_l00002onK<P0?o00000_oVc803o`00053o
i/b000?o0000onK<P?oVc8000ooVc80000ooi/b000?o0000onK<P?oVc8001OoVc8000ol0003oi/b0
onK<P00`onK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<P?oVc8002OoVc802o`0000;oi/b0
0ol00002onK<P0Co000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002o`000003onK<
P?l0003o000000;o00000_oVc803o`0000;oi/b00ol00002onK<P0;o0000<_oVc8000ol0003oi/b0
onK<P00aonK<P003o`000?oVc83oi/b000?oi/b0000?onK<P003o`000?oVc83oi/b000Goi/b00ol0
0002onK<P0?o00000_oVc803o`0000;oi/b01?l000000ooVc83o0000o`000002o`000003onK<P?l0
003o000000;o00000_oVc803o`0000;oi/b00ol00002onK<P0Co000000?oi/b0o`000?l000000_l0
00000ooVc83o0000o`000002o`0000;oi/b00ol00002onK<P0?o00000_oVc803o`0000;oi/b01?l0
00000ooVc83o0000o`000002o`000003onK<P?l0003o000000;o00000_oVc803o`0000;oi/b00ol0
0002onK<P0Co000000?oi/b0o`000?l000000_l000000ooVc83o0000o`000002o`0000;oi/b000?o
0000onK<P?l000003?oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o
0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o
0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o
0000onK<P?oVc8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000?oi/b0000?
onK<P003o`000?oVc83oi/b000Goi/b0ool00005o`0000Goi/b0000?onK<P003o`000?oVc83oi/b0
0?ooi/b03ooVc80000koi/b00_l0003oonK<P17oi/b0000?onK<P003o`000?oVc83oi/b00?ooi/b0
3ooVc8000?ooi/b08OoVc8000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classic Effective for constant population", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      1\/2\ \((1 + \((\(-1\) + m)\)\^2 + 
              m\^2\/\(\(-1\) + nd\) + \(m\ \((2 + \((\(-2\) + m)\)\ nd)\)\)\/\
\((\(-1\) + nd)\)\^2 - \(1 - 2\ m + \(m\^2\ nd\)\/\(\(-1\) + nd\)\)\/n + \
\[Sqrt]\((\(1\/\(n\^2\ \((\(-1\) + nd)\)\^4\)\) \((4\ m\ \((1 + 
                              n\ \((\(-2\) + nd)\) - 
                              nd)\)\ \((\(-1\) + nd)\)\^3 + \((\(-1\) + nd)\)\
\^4 - 4\ m\^3\ \((\(-1\) + nd)\)\ nd\ \((1 + \((\(-1\) + n)\)\ nd)\)\^2 + 
                        m\^4\ nd\^2\ \((1 + \((\(-1\) + n)\)\ nd)\)\^2 + 
                        2\ m\^2\ \((\(-1\) + nd)\)\^2\ \((2 + \((\(-5\) + 
                                    6\ n)\)\ nd + \((3 - 5\ n + 
                                    2\ n\^2)\)\ nd\^2)\))\))\))\) /. {n \
\[Rule] 5, nd \[Rule] 3}, {m, 0, 1}, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
      Frame \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.00942 .61267 L
.01975 .60775 L
.04057 .60026 L
.05163 .59727 L
.06347 .59463 L
.08481 .59097 L
.10718 .58817 L
.12833 .58618 L
.16866 .58349 L
.18949 .58248 L
.21157 .5816 L
.2513 .58037 L
.2936 .57941 L
.33431 .57873 L
.3776 .57817 L
.41929 .57776 L
.45939 .57746 L
.50207 .57721 L
.54316 .57704 L
.56564 .57697 L
.58682 .57692 L
.59707 .5769 L
.6079 .57688 L
.61805 .57686 L
.6273 .57685 L
.63725 .57684 L
.64273 .57684 L
.64792 .57684 L
.65271 .57683 L
.65714 .57683 L
.65945 .57683 L
.66078 .57683 L
.662 .57683 L
.66328 .57683 L
.66466 .57683 L
.66588 .57683 L
.66717 .57683 L
.66846 .57683 L
.66919 .57683 L
.66987 .57683 L
.67111 .57683 L
.67242 .57683 L
.67469 .57683 L
.67719 .57683 L
.67986 .57683 L
.68272 .57684 L
.6879 .57684 L
.69797 .57684 L
.70718 .57685 L
Mistroke
.72715 .57688 L
.73845 .5769 L
.74893 .57692 L
.79007 .57704 L
.81259 .57713 L
.83379 .57722 L
.87432 .57746 L
.91743 .57779 L
.95894 .5782 L
.99887 .57872 L
1 .57874 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooVc80Q
onK<P000@ooVc802o`0000Coi/b000Co0000onK<P?oVc83oi/b01Ol0000UonK<P0;o00001?oVc800
0ol0003oi/b0onK<P003onK<P0?o00009OoVc802o`0000Coi/b000?o0000onK<P?oVc8000_oVc803
o`0002Koi/b00_l00004onK<P003o`000?oVc83oi/b000;oi/b00ol0000[onK<P0?o00001OoVc800
04;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<P?l0000TonK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8008ooVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000009?oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83o
i/b0onK<P?l00000:ooVc8000ol0003oi/b0onK<P004onK<P000@_oVc8001?l0003oi/b0onK<P?l0
0009onK<P003o`000?oVc83oi/b002Coi/b000Co0000onK<P?oVc83o00001ooVc805o`0002Coi/b0
00Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002Coi/b000Co0000onK<
P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000002_oi/b000?o0000onK<P?oVc8001?oV
c80004;oi/b000Co0000onK<P?oVc83o00002_oVc8000ol0003oi/b0onK<P00SonK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00009OoVc8001?l0003oi/b0onK<P?l00007onK<
P0Co00009OoVc8001?l0003oi/b0onK<P?l00008onK<P0?o0000;?oVc8000ol0003oi/b0onK<P004
onK<P000@_oVc8001?l0003oi/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000009?oV
c8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000002Goi/b000Co0000onK<P?oVc83o
00001ooVc8000ol0003oi/b0onK<P00VonK<P004o`000?oVc83oi/b0o`0000Ooi/b000Go0000onK<
P?oVc83oi/b0o`00000[onK<P003o`000?oVc83oi/b000Coi/b00012onK<P004o`000?oVc83oi/b0
o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`00000TonK<P004o`000?oVc83oi/b0o`0000Woi/b0
0_l0000UonK<P004o`000?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8009OoVc8001?l0003o
i/b0onK<P?l00007onK<P005o`000?oVc83oi/b0onK<P?l00000:_oVc802o`0000Koi/b00013onK<
P0;o00002OoVc803o`0002Koi/b00_l0000;onK<P003o`000?oVc83oi/b002Coi/b00_l0000:onK<
P0;o00009_oVc802o`0000Woi/b00ol0000/onK<P003o`000?oVc83oi/b000Coi/b0003oonK<P27o
i/b0003oonK<P27oi/b0003oonK<P27oi/b0003oonK<P27oi/b0000GonK<P?oo00001Ol00005onK<
P0005ooVc8000ol0003oi/b0onK<P009onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoV
c8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000
onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l00004
onK<P004o`000?oVc83oi/b0onK<P0Go00001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00002?oVc8001?l0003oi/b0onK<
P?l00005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oV
c8001?l0003oi/b0onK<P?l00009onK<P003o`000?oVc83oi/b000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000[oi/b0
00?o0000onK<P?oVc8001?oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<
P?l00007onK<P005o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003o
i/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b00003onK<P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<
P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc800
01Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003
o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<
P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000ooVc802o`0000Coi/b000?o0000onK<P?oVc8000ooVc803o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000[oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc805o`0000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Co0000onK<P?oVc83o00001_oVc802o`000?ooi/b00ol00005onK<P000
0_oVc8001?l0003oi/b0onK<P?l00008onK<P003o`000?oVc83o000000Koi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Wo
i/b00_l00006onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
0ooVc802o`0000_oi/b000?o0000onK<P?oVc8001?oVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oV
c83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003
onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`00
0?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83o
i/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03o
onK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc802o`00
00Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003
o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0
onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<P002onK<P0?o00001_oV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80000;oi/b000Co0000
onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oVc83oi/b0o`0000Ooi/b0
00Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P0Co00001_oVc802o`000?oo
i/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P003o`000?oVc83oi/b000Oo
i/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`00
0?oVc83oi/b0o`0000Soi/b000?o0000onK<P?oVc8001_oVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80000?oi/b00_l0000:onK<P0;o00001_oVc8000ol0003oi/b0
onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooV
c801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc800
0ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc8000ol0003oi/b0onK<
P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801
onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0
003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oV
c8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0
000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc802o`0000Goi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003o
i/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc800
0ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000G
onK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0
003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oV
c800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b0
0OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P0;o00001OoV
c80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<
P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003o
i/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800
oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<P0;o00001?oVc8000ol0003oi/b0onK<
P002onK<P0?o00001_oVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooV
c80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o000000Goi/b0
00?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00002onK<P004o`000?oV
c83oi/b0o`0000Ooi/b000Go0000onK<P?oVc83oi/b0o`000005onK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0000_oVc8001?l0003oi/b0onK<P?l00008onK<P0?o
00001_oVc802o`000?ooi/b00ol00005onK<P0000_oVc8001?l0003oi/b0onK<P?l00007onK<P005
o`000?oVc83oi/b0onK<P?l000001OoVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<
P?oVc8000ooVc80000;oi/b000Co0000onK<P?oVc83o00001ooVc8001Ol0003oi/b0onK<P?oVc83o
000000Goi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b00003onK<
P0;o00002OoVc803o`0000Koi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b0
00?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P000
5ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o
0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<
P0;o00001OoVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?o
i/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooV
c8000ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000
onK<P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
0?ooi/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07o
i/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800oooVc801onK<P003o`00
0?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?ooi/b00_l00005onK<P0005ooVc800
0ol0003oi/b0onK<P03oonK<P07oi/b000?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<
P?oVc800oooVc801onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b00?oo
i/b00OoVc8000ol0003oi/b0onK<P003onK<P0005ooVc8000ol0003oi/b0onK<P03oonK<P07oi/b0
00?o0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800KooVc81go`0001[oi/b000?o
0000onK<P?oVc8000ooVc80001Ooi/b000?o0000onK<P?oVc800>OoVc80fo`0007Ooi/b06ol00005
onK<P0005ooVc8000ol0003oi/b0onK<P00SonK<P1Ko0000aooVc8000ol0003oi/b0onK<P003onK<
P0005ooVc8000ol0003oi/b0onK<P00FonK<P0go0000g?oVc802o`0000Goi/b0000GonK<P003o`00
0?oVc83oi/b0013oi/b01_l0003ZonK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oV
c83oi/b000coi/b01?l0003`onK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83o
i/b000Koi/b01_l0003donK<P003o`000?oVc83oi/b000?oi/b0000GonK<P003o`000?oVc83oi/b0
00?oi/b00ol0003jonK<P003o`000?oVc83oi/b000?oi/b0000>onK<P0?o00001_oVc8001?l0003o
i/b0onK<P?oVc802o`000?goi/b000?o0000onK<P?oVc8000ooVc80000ooi/b000?o0000onK<P?oV
c8001OoVc8001?l0003oi/b0onK<P?l0000_onK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<
P?oVc800<OoVc8000ol0003oi/b0onK<P00aonK<P003o`000?oVc83oi/b0037oi/b000?o0000onK<
P?oVc8000ooVc80000ooi/b000?o0000onK<P?oVc8001OoVc803o`0000Woi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P00:onK<P003o`000?oVc83oi/b000[oi/b000?o0000onK<P?oV
c8002_oVc8000ol0003oi/b0onK<P003onK<P0003ooVc8000ol0003oi/b0onK<P005onK<P?oo0000
1Ol00005onK<P0003ooVc8000ol0003oi/b0onK<P03oonK<P0ooi/b0000>onK<P0;o0000oooVc80A
onK<P0003ooVc8000ol0003oi/b0onK<P03oonK<P0ooi/b0003oonK<P27oi/b00000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["One pop  three states", "Section"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "e1", "e2"},
            {
              "0", \(\((1 - e1)\)\ \ \[Alpha]\), \(\((1 - 
                    e2)\)\ \ \((1 - \[Beta])\)\)},
            {
              "0", \(\((1 - e1)\)\ \ \((1 - \[Alpha])\)\), \(\[Beta] \((1 - 
                    e2)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\((1 - e1)\)\ \[Alpha]\), \(\((1 - 
                    e2)\)\ \((1 - \[Beta])\)\)},
            {\(\((1 - e1)\)\ \((1 - \[Alpha])\)\), \(\((1 - e2)\)\ \[Beta]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[{{\[Alpha] \((1 - e1)\), \((1 - \[Beta])\) \((1 - 
                  e2)\)}, {\((1 - \[Alpha])\) \((1 - e1)\), \[Beta] \((1 - 
                  e2)\)}}] // Simplify\)], "Input"],

Cell[BoxData[
    \({1\/2\ \((\[Alpha] - e1\ \[Alpha] + \[Beta] - 
            e2\ \[Beta] - \@\(\(-4\)\ \((\(-1\) + e1)\)\ \((\(-1\) + e2)\)\ \
\((\(-1\) + \[Alpha] + \[Beta])\) + \((\((\(-1\) + e1)\)\ \[Alpha] + \
\((\(-1\) + e2)\)\ \[Beta])\)\^2\))\), 
      1\/2\ \((\[Alpha] - e1\ \[Alpha] + \[Beta] - 
            e2\ \[Beta] + \@\(\(-4\)\ \((\(-1\) + e1)\)\ \((\(-1\) + e2)\)\ \
\((\(-1\) + \[Alpha] + \[Beta])\) + \((\((\(-1\) + e1)\)\ \[Alpha] + \
\((\(-1\) + e2)\)\ \[Beta])\)\^2\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {n2 \[Rule] 5, 
        n1 \[Rule] 5, \[Beta] \[Rule] 0.8, \[Alpha] \[Rule] 0.8, 
        e1 \[Rule] 0, e2 \[Rule] 0.3}\)], "Input"],

Cell[BoxData[
    \({0.47408739718026033`, 0.8859126028197397`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\((1 - e1)\)\ \((1 - 1\/n1)\)\ \[Alpha]\), \(\((1 - 
                    e2)\)\ \((1 - 1\/n2)\)\ \((1 - \[Beta])\)\)},
            {\(\((1 - e1)\)\ \((1 - 1\/n1)\)\ \((1 - \[Alpha])\)\), \(\((1 - 
                    e2)\)\ \((1 - 1\/n2)\)\ \[Beta]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[{{\[Alpha] \((1 - e1)\) \((1 - 
                  1\/n1)\), \((1 - \[Beta])\) \((1 - e2)\) \((1 - 
                  1\/n2)\)}, {\((1 - \[Alpha])\) \((1 - e1)\) \((1 - 
                  1\/n1)\), \[Beta] \((1 - e2)\) \((1 - 1\/n2)\)}}] // 
      Simplify\)], "Input"],

Cell[BoxData[
    \({\(-\(\(1\/\(2\ n1\ n2\)\)\((n2\ \[Alpha] - e1\ n2\ \[Alpha] - 
            n1\ n2\ \[Alpha] + e1\ n1\ n2\ \[Alpha] + n1\ \[Beta] - 
            e2\ n1\ \[Beta] - n1\ n2\ \[Beta] + 
            e2\ n1\ n2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + 
                        e1)\)\ \((\(-1\) + e2)\)\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \[Alpha] + \[Beta])\) + \((\((\
\(-1\) + e2)\)\ n1\ \[Beta] - n2\ \((\((\(-1\) + e1)\)\ \((\(-1\) + n1)\)\ \
\[Alpha] + \((\(-1\) + e2)\)\ n1\ \[Beta])\))\)\^2)\))\)\)\), \(\(1\/\(2\ n1\ \
n2\)\)\((\(-n2\)\ \[Alpha] + e1\ n2\ \[Alpha] + n1\ n2\ \[Alpha] - 
          e1\ n1\ n2\ \[Alpha] - n1\ \[Beta] + e2\ n1\ \[Beta] + 
          n1\ n2\ \[Beta] - 
          e2\ n1\ n2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + 
                      e1)\)\ \((\(-1\) + e2)\)\ \((\(-1\) + 
                      n1)\)\ n1\ \((\(-1\) + 
                      n2)\)\ n2\ \((\(-1\) + \[Alpha] + \[Beta])\) + \
\((\((\(-1\) + e2)\)\ n1\ \[Beta] - n2\ \((\((\(-1\) + e1)\)\ \((\(-1\) + n1)\
\)\ \[Alpha] + \((\(-1\) + e2)\)\ n1\ \[Beta])\))\)\^2)\))\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {n2 \[Rule] 5, 
        n1 \[Rule] 5, \[Beta] \[Rule] 0.8, \[Alpha] \[Rule] 0.8, 
        e1 \[Rule] 0, e2 \[Rule] 0.3}\)], "Input"],

Cell[BoxData[
    \({0.37926991774420826`, 0.7087300822557918`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(-\(\(1\/\(2\ n1\ n2\)\) \((n2\ \[Alpha] - e1\ n2\ \[Alpha] - 
                n1\ n2\ \[Alpha] + e1\ n1\ n2\ \[Alpha] + n1\ \[Beta] - 
                e2\ n1\ \[Beta] - n1\ n2\ \[Beta] + 
                e2\ n1\ n2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + 
                            e1)\)\ \((\(-1\) + e2)\)\ \((\(-1\) + 
                            n1)\)\ n1\ \((\(-1\) + 
                            n2)\)\ n2\ \((\(-1\) + \[Alpha] + \[Beta])\) + \
\((\((\(-1\) + e2)\)\ n1\ \[Beta] - n2\ \((\((\(-1\) + e1)\)\ \((\(-1\) + n1)\
\)\ \[Alpha] + \((\(-1\) + e2)\)\ n1\ \[Beta])\))\)\^2)\))\)\)\), \(1\/\(2\ \
n1\ n2\)\) \((\(-n2\)\ \[Alpha] + e1\ n2\ \[Alpha] + n1\ n2\ \[Alpha] - 
              e1\ n1\ n2\ \[Alpha] - n1\ \[Beta] + e2\ n1\ \[Beta] + 
              n1\ n2\ \[Beta] - 
              e2\ n1\ n2\ \[Beta] + \[Sqrt]\((\(-4\)\ \((\(-1\) + 
                          e1)\)\ \((\(-1\) + e2)\)\ \((\(-1\) + 
                          n1)\)\ n1\ \((\(-1\) + 
                          n2)\)\ n2\ \((\(-1\) + \[Alpha] + \[Beta])\) + \
\((\((\(-1\) + e2)\)\ n1\ \[Beta] - n2\ \((\((\(-1\) + e1)\)\ \((\(-1\) + n1)\
\)\ \[Alpha] + \((\(-1\) + e2)\)\ n1\ \[Beta])\))\)\^2)\))\)} /. {n2 \[Rule] 
          5, n1 \[Rule] 5, \[Beta] \[Rule] 0.8, \[Alpha] \[Rule] 0.8, 
        e1 \[Rule] 0, e2 \[Rule] 0.3}\)], "Input"],

Cell[BoxData[
    \({0.37926991774420826`, 0.7087300822557918`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spom demography", "Section"],

Cell[CellGroupData[{

Cell["SpomTwoPop", "Subsection"],

Cell[BoxData[
    \(\(nd = 2;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
        Delete[Transpose[
            Delete[Partition[
                Flatten[
                  Table[Flatten[
                      Table[P[
                          Table[1 - KroneckerDelta[do\_i], {i, 1, 
                                nd}] \[VerticalSeparator] 
                            Table[1 - KroneckerDelta[po\_i], {i, 1, 
                                nd}]], {po\_1, 0, 1}, {po\_2, 0, 
                          1}]], {do\_1, 0, 1}, {do\_2, 0, 1}]], 
                2\^nd], {1}]], {1}]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(P[{0, 1} \[VerticalSeparator] {0, 1}]\), \(P[{0, 
                    1} \[VerticalSeparator] {1, 0}]\), \(P[{0, 
                    1} \[VerticalSeparator] {1, 1}]\)},
            {\(P[{1, 0} \[VerticalSeparator] {0, 1}]\), \(P[{1, 
                    0} \[VerticalSeparator] {1, 0}]\), \(P[{1, 
                    0} \[VerticalSeparator] {1, 1}]\)},
            {\(P[{1, 1} \[VerticalSeparator] {0, 1}]\), \(P[{1, 
                    1} \[VerticalSeparator] {1, 0}]\), \(P[{1, 
                    1} \[VerticalSeparator] {1, 1}]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(P[{do\_1, 
            do\_2} \[VerticalSeparator] {po\_1, 
            po\_2}] \[Equal] \[Product]\+\(i = 1\)\%nd\(\((P\_i[
                  0 \[VerticalSeparator] {po\_1, po\_2}])\)\^KroneckerDelta[
                do\_i]\) \((1 - \((P\_i[0 \[VerticalSeparator] {po\_1, \
po\_2}])\))\)\^\((1 - KroneckerDelta[do\_i])\)\[IndentingNewLine]
    \(\(\[Equal]\)\(\[Product]\+\(i = 1\)\%nd\(\((P\_i[
                  0 \[VerticalSeparator] 
                    Table[1 - KroneckerDelta[po\_i], {i, 1, 
                        nd}]])\)\^KroneckerDelta[
                do\_i]\) \((1 - \((P\_i[0 \[VerticalSeparator] Table[1 - \
KroneckerDelta[po\_i], {i, 1, nd}]])\))\)\^\((1 - \
KroneckerDelta[do\_i])\)\)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(nd = 2;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
        Delete[Transpose[
            Delete[Partition[
                Flatten[
                  Table[Flatten[
                      Table[\[Product]\+\(i = 1\)\%nd\(\((P\_i[
                                    0 \[VerticalSeparator] 
                                      Table[
                                        1 - KroneckerDelta[po\_i], {i, 1, 
                                        nd}]])\)\^KroneckerDelta[
                                  do\_i]\) \((1 - \((P\_i[0 \
\[VerticalSeparator] Table[1 - KroneckerDelta[po\_i], {i, 1, \
nd}]])\))\)\^\((1 - KroneckerDelta[do\_i])\), {po\_1, 0, 1}, {po\_2, 0, 
                          1}]], {do\_1, 0, 1}, {do\_2, 0, 1}]], 
                2\^nd], {1}]], {1}]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(P\_1[
                  0 \[VerticalSeparator] {0, 1}]\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {0, 1}])\)\), \(P\_1[
                  0 \[VerticalSeparator] {1, 0}]\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {1, 0}])\)\), \(P\_1[
                  0 \[VerticalSeparator] {1, 1}]\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {1, 1}])\)\)},
            {\(\((1 - P\_1[0 \[VerticalSeparator] {0, 1}])\)\ P\_2[
                  0 \[VerticalSeparator] {0, 1}]\), \(\((1 - 
                    P\_1[0 \[VerticalSeparator] {1, 0}])\)\ P\_2[
                  0 \[VerticalSeparator] {1, 0}]\), \(\((1 - 
                    P\_1[0 \[VerticalSeparator] {1, 1}])\)\ P\_2[
                  0 \[VerticalSeparator] {1, 1}]\)},
            {\(\((1 - P\_1[0 \[VerticalSeparator] {0, 1}])\)\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {0, 1}])\)\), \(\((1 - 
                    P\_1[0 \[VerticalSeparator] {1, 0}])\)\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {1, 0}])\)\), \(\((1 - 
                    P\_1[0 \[VerticalSeparator] {1, 1}])\)\ \((1 - 
                    P\_2[0 \[VerticalSeparator] {1, 1}])\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(P[{do\_1, 
              do\_2} \[VerticalSeparator] {po\_1, 
              po\_2}] \[Equal] \((\[Product]\+\(i = 1\)\%nd\(\((\((e\_i + \
\((1 - e\_i)\) Exp[\(-\((\[Sum]\+\(j = 1\)\%nd\((KroneckerDelta[i, 
                                        j] \((1 - d)\) + \((1 - 
                                        KroneckerDelta[i, j])\) d)\) \((1 - 
                                        KroneckerDelta[po\_j])\) 
                                    b\ n\_j)\)\)])\))\)\^KroneckerDelta[
                    do\_i]\) \((1 - \((\((e\_i + \((1 - e\_i)\) Exp[\(-\((\
\[Sum]\+\(j = 1\)\%nd\((\((KroneckerDelta[i, j] \((1 - d)\) + \((1 - \
KroneckerDelta[i, j])\) d)\))\) \((1 - KroneckerDelta[po\_j])\) b\ \
n\_j)\)\)])\))\))\)\^\((1 - KroneckerDelta[do\_i])\))\) /. {e\_1 \[Rule] e1, 
        e\_2 \[Rule] e2, e\_3 \[Rule] e3, n\_1 \[Rule] n1, n\_2 \[Rule] n2, 
        n\_3 \[Rule] n3}\)\)\)], "Input"],

Cell[BoxData[
    \(P[{do\_1, do\_2} \[VerticalSeparator] {po\_1, 
            po\_2}] \[Equal] \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - KroneckerDelta[po\_2])\
\)\)\ \((1 - e1)\) - e1)\)\^\(1 - KroneckerDelta[do\_1]\)\ \((\[ExponentialE]\
\^\(\(-b\)\ \((1 - d)\)\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 \
- KroneckerDelta[po\_2])\)\)\ \((1 - e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ \
\((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) - e2)\)\^\(1 \
- KroneckerDelta[do\_2]\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) + e2)\)\^KroneckerDelta[do\_2]\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
        Delete[Transpose[
            Delete[Partition[
                Flatten[
                  Table[Flatten[
                      Table[\((\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - KroneckerDelta[po\_2])\
\)\)\ \((1 - e1)\) - e1)\)\^\(1 - KroneckerDelta[do\_1]\)\ \((\[ExponentialE]\
\^\(\(-b\)\ \((1 - d)\)\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 \
- KroneckerDelta[po\_2])\)\)\ \((1 - e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ \
\((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) - e2)\)\^\(1 \
- KroneckerDelta[do\_2]\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) + e2)\)\^KroneckerDelta[do\_2])\), \
{po\_1, 0, 1}, {po\_2, 0, 1}]], {do\_1, 0, 1}, {do\_2, 0, 1}]], 
                2\^nd], {1}]], {1}]] // MatrixForm\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"indet\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\), \(\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - 
                    e2)\)\), \(\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\)},
            {\(\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) + 
                    e2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + e2)\)\)},
            {\(\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - 
                    e2)\)\), \(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"indet\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \({{\((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                    e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                    e2)\) - 
              e2)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\
\ n2\)\ \((1 - e2)\) - 
              e2)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                    e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - 
                    e2)\) + 
              e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
              e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\
\)\ \((1 - e2)\) + 
              e2)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                    e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                    e2)\) - 
              e2)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\
\ n2\)\ \((1 - e2)\) - e2)\)}}\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {e1 \[Rule] 0, e2 \[Rule] 0} // Simplify\)], "Input"],

Cell[BoxData[
    \({{\(-\[ExponentialE]\^\(\(-b\)\ n2\)\) + \[ExponentialE]\^\(\(-b\)\ d\ \
n2\), \[ExponentialE]\^\(\(-b\)\ n1\)\ \((\(-1\) + \[ExponentialE]\^\(b\ d\ \
n1\))\), \[ExponentialE]\^\(\(-b\)\ \((n1 + n2)\)\)\ \((\(-1\) + \
\[ExponentialE]\^\(b\ \((d\ \((n1 - n2)\) + n2)\)\))\)}, {\[ExponentialE]\^\(\
\(-b\)\ n2\)\ \((\(-1\) + \[ExponentialE]\^\(b\ d\ n2\))\), \
\(-\[ExponentialE]\^\(\(-b\)\ n1\)\) + \[ExponentialE]\^\(\(-b\)\ d\ n1\), \
\[ExponentialE]\^\(\(-b\)\ \((n1 + n2)\)\)\ \((\(-1\) + \[ExponentialE]\^\(b\ \
\((n1 - d\ n1 + d\ n2)\)\))\)}, {\[ExponentialE]\^\(\(-b\)\ n2\)\ \((\(-1\) + \
\[ExponentialE]\^\(\(-b\)\ \((\(-1\) + d)\)\ n2\))\)\ \((\(-1\) + \
\[ExponentialE]\^\(b\ d\ n2\))\), \[ExponentialE]\^\(\(-b\)\ n1\)\ \((\(-1\) \
+ \[ExponentialE]\^\(\(-b\)\ \((\(-1\) + d)\)\ n1\))\)\ \((\(-1\) + \
\[ExponentialE]\^\(b\ d\ n1\))\), \[ExponentialE]\^\(\(-b\)\ \((n1 + n2)\)\)\ \
\((\(-1\) + \[ExponentialE]\^\(b\ \((d\ \((n1 - n2)\) + n2)\)\))\)\ \((\(-1\) \
+ \[ExponentialE]\^\(b\ \((n1 - d\ n1 + d\ n2)\)\))\)}}\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpomThreePop", "Subsection"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nd = 3;\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(P[{do\_1, do\_2, do\_3} \[VerticalSeparator] {po\_1, po\_2, 
              po\_3}] \[Equal] \((\[Product]\+\(i = 1\)\%nd\(\((\((e\_i + \
\((1 - e\_i)\) Exp[\(-\((\[Sum]\+\(j = 1\)\%nd\((\((KroneckerDelta[i, 
                                        j] \((1 - d)\) + \((1 - 
                                        KroneckerDelta[i, 
                                        j])\) \((d\ \[CapitalLambda]\_\(i, \
j\))\))\))\) \((1 - KroneckerDelta[po\_j])\) 
                                    b\ n\_j)\)\)])\))\)\^KroneckerDelta[
                    do\_i]\) \((1 - \((\((e\_i + \((1 - e\_i)\) Exp[\(-\((\
\[Sum]\+\(j = 1\)\%nd\((\((KroneckerDelta[i, j] \((1 - d)\) + \((1 - \
KroneckerDelta[i, j])\) \((d\ \[CapitalLambda]\_\(i, j\))\))\))\) \((1 - \
KroneckerDelta[po\_j])\) b\ n\_j)\)\)])\))\))\)\^\((1 - \
KroneckerDelta[do\_i])\))\) /. {e\_1 \[Rule] e1, e\_2 \[Rule] e2, 
        e\_3 \[Rule] e3, n\_1 \[Rule] n1, n\_2 \[Rule] n2, 
        n\_3 \[Rule] 
          n3, \[CapitalLambda]\_\(1, 3\) \[Rule] \[CapitalLambda]13, \
\[CapitalLambda]\_\(2, 3\) \[Rule] 
          1 - \[CapitalLambda]13, \[CapitalLambda]\_\(1, 2\) \[Rule] \
\[CapitalLambda]12, \[CapitalLambda]\_\(3, 2\) \[Rule] 
          1 - \[CapitalLambda]12, \[CapitalLambda]\_\(2, 1\) \[Rule] \
\[CapitalLambda]21, \[CapitalLambda]\_\(3, 1\) \[Rule] 
          1 - \[CapitalLambda]21}\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(\[CapitalLambda]21\\)\\\" is similar to \
existing symbol \\\"\\!\\(\[CapitalLambda]12\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(P[{do\_1, do\_2, do\_3} \[VerticalSeparator] {po\_1, po\_2, 
            po\_3}] \[Equal] \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \[CapitalLambda]12\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \[CapitalLambda]13\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) - e1)\)\^\(1 - KroneckerDelta[do\_1]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \[CapitalLambda]12\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \[CapitalLambda]13\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) - e2)\)\^\(1 - KroneckerDelta[do\_2]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) + e2)\)\^KroneckerDelta[do\_2]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) - e3)\)\^\(1 - KroneckerDelta[do\_3]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) + e3)\)\^KroneckerDelta[do\_3]\)], \
"Output"]
}, Closed]],

Cell[BoxData[
    \(\(nd = 3;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
      Delete[Transpose[
          Delete[Partition[
              Flatten[Table[
                  Flatten[
                    Table[\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\ \
\((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \[CapitalLambda]12\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \[CapitalLambda]13\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) - e1)\)\^\(1 - KroneckerDelta[do\_1]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \[CapitalLambda]12\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \[CapitalLambda]13\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) - e2)\)\^\(1 - KroneckerDelta[do\_2]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) + e2)\)\^KroneckerDelta[do\_2]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) - e3)\)\^\(1 - KroneckerDelta[do\_3]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) + e3)\)\^KroneckerDelta[do\_3], \
{po\_1, 0, 1}, {po\_2, 0, 1}, {po\_3, 0, 1}]], {do\_1, 0, 1}, {do\_2, 0, 
                    1}, {do\_3, 0, 1}]], 2\^nd], {1}]], {1}]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"indet\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({{\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                    e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                    e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n1\
\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) - 
              e3)\)}, {\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 - 
                    e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                    e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n1\
\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) + 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
              e3)\)}, {\((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - 
                    e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) - 
              e3)\), \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) - 
              e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 - 
                    e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n1\
\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n1\
\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
              e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n1\
\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ n3\
\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) + 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) - 
              e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \((1 - 
                    e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n1\
\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) + 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) - 
              e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ n2\
\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \
\((1 - e3)\) + 
              e3)\)}, {\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                    e3)\) - 
              e3)\), \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
              e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                    e2)\) - 
              e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) - e3)\)}}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spom demogenetics", "Section"],

Cell[CellGroupData[{

Cell["SpomTwoPop", "Subsection"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nd = 2;\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\((F = \((Table[\((\((\((KroneckerDelta[i, 
                                j] \((1 - d)\) + \((1 - 
                                  KroneckerDelta[i, j])\) d)\))\) \((1 - 
                          KroneckerDelta[po\_j])\) 
                      n\_j)\)/\((\[Sum]\+\(j = 1\)\%nd\((\((\((KroneckerDelta[
                                    i, j] \((1 - d)\) + \((1 - 
                                      KroneckerDelta[i, j])\) d)\))\) \((1 - 
                              KroneckerDelta[po\_j])\) n\_j)\))\), {i, 1, 
                  nd}, {j, 1, nd}] /. {n\_1 \[Rule] n1, n\_2 \[Rule] n2, 
                n\_3 \[Rule] n3})\))\) // MatrixForm\)\)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\((1 - d)\)\ n1\ \((1 - 
                        KroneckerDelta[po\_1])\)\)\/\(\((1 - d)\)\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    d\ n2\ \((1 - 
                          KroneckerDelta[po\_2])\)\)\), \(\(d\ n2\ \((1 - 
                        KroneckerDelta[po\_2])\)\)\/\(\((1 - d)\)\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    d\ n2\ \((1 - KroneckerDelta[po\_2])\)\)\)},
            {\(\(d\ n1\ \((1 - 
                        KroneckerDelta[po\_1])\)\)\/\(d\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + \((1 - d)\)\ n2\ \((1 - 
                          KroneckerDelta[po\_2])\)\)\), \(\(\((1 - 
                        d)\)\ n2\ \((1 - 
                        KroneckerDelta[po\_2])\)\)\/\(d\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + \((1 - d)\)\ n2\ \((1 - 
                          KroneckerDelta[po\_2])\)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Diag = \((DiagonalMatrix[
                Flatten[
                  ReplacePart[
                    Table[ReplacePart[Table[0, {i, 1, nd + 1}], 1\/n\_i, 
                        1], {i, 1, nd}], 1\/n\_nd, nd]]] /. {n\_1 \[Rule] n1, 
                n\_2 \[Rule] n2, n\_3 \[Rule] n3})\))\) // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/n1\), "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", \(1\/n2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((G = 
          KroneckerProduct[F, F] - \((KroneckerProduct[F, F] . Diag)\) // 
            Simplify)\) // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\((\(-1\) + d)\)\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\((n1 - d\ n1 + d\ n2 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ KroneckerDelta[po\_2])\)\^2\), \
\(-\(\(\((\(-1\) + d)\)\ d\ n1\ n2\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n1 - d\ n1 + d\ n2 + \((\(-1\) + \
d)\)\ n1\ KroneckerDelta[po\_1] - d\ n2\ KroneckerDelta[po\_2])\)\^2\)\), \(-\
\(\(\((\(-1\) + d)\)\ d\ n1\ n2\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n1 - d\ n1 + d\ n2 + \((\(-1\) + \
d)\)\ n1\ KroneckerDelta[po\_1] - d\ n2\ KroneckerDelta[po\_2])\)\^2\)\), \
\(\(d\^2\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\((n1 - d\ n1 + d\ n2 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ KroneckerDelta[po\_2])\)\^2\)},
            {\(\(\((1 - d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_2])\))\)\)\), \(\(\((\(-1\) + d)\)\^2\ n1\
\ n2\ \((1 - KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_2])\))\)\)\), \(\(d\^2\ n1\ n2\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\)\), \(\(\((1 - 
                        d)\)\ d\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + KroneckerDelta[po\_2])\))\)\)\)},
            {\(\(\((1 - d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_2])\))\)\)\), \(\(d\^2\ n1\ n2\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_2])\))\)\)\), \(\(\((\(-1\) + d)\)\^2\ n1\
\ n2\ \((1 - KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\)\), \(\(\((1 - 
                        d)\)\ d\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\(\((\(-d\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \((\(-1\) + KroneckerDelta[po\_2])\))\)\)\)},
            {\(\(\((\(-1\) + 
                        n1)\)\ n1\ \((d - d\ \
KroneckerDelta[po\_1])\)\^2\)\/\((d\ n1\ \((\(-1\) + KroneckerDelta[po\_1])\) \
- \((\(-1\) + d)\)\ n2\ \((\(-1\) + KroneckerDelta[po\_2])\))\)\^2\), \(-\(\(\
\((\(-1\) + d)\)\ d\ n1\ n2\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((\(-d\)\ n1 - n2 + d\ n2 + d\ n1\ \
KroneckerDelta[po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[po\_2])\)\^2\)\), \
\(-\(\(\((\(-1\) + d)\)\ d\ n1\ n2\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((\(-d\)\ n1 - n2 + d\ n2 + d\ n1\ \
KroneckerDelta[po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[po\_2])\)\^2\)\), \(\
\(\((\(-1\) + d)\)\^2\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\((\(-d\)\ n1 - n2 + d\ n2 + d\ n1\ \
KroneckerDelta[po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[po\_2])\)\^2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
      Delete[Transpose[
          Delete[\((Partition[
                Flatten[
                  Table[Flatten[
                      Table[Table[\((\((\((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \
KroneckerDelta[po\_2])\)\)\ \((1 - e1)\) - e1)\)\^\(1 - KroneckerDelta[do\_1]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - KroneckerDelta[po\_2])\)\)\ \((1 \
- e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ \
n1\ \((1 - KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) - e2)\)\^\(1 - KroneckerDelta[do\_2]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ \
\((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\)\)\ \((1 - e2)\) + \
e2)\)\^KroneckerDelta[do\_2])\) 
                              G\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\), {po\_1, 0, 1}, {po\_2, 0, 1}], {i, 1, 
                          4}]], {do\_1, 0, 1}, {do\_2, 0, 1}]], \(nd\^2\) 
                  2\^nd])\), Table[{i}, {i, 1, nd\^2}]]], 
        Table[{i}, {i, 1, nd\^2}]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \\(\\((1 - d)\\)\\)\\\\ d\\\\ \\(\\((\\(\\(-1\\)\\) + \
n1)\\)\\)\\\\ n1\\\\ ComplexInfinity\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"infy\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \\((\\(\\(-1\\)\\) + d)\\)\\^2\\\\ n1\\\\ n2\\\\ \
ComplexInfinity\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ d\\^2\\\\ n1\\\\ n2\\\\ ComplexInfinity\\\\ \
ComplexInfinity\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(\[Infinity] :: \\\"indet\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"indet\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({{0, 0, 
        0, \(d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) + \
e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - \
e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2)\
\)\^2, \(\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\
\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((n1 - d\ n1)\)\^2, 0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\((n1 - d\ n1 + d\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(-\(\(\
\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + \
e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 0, 
        0, \(-\(\(\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + 
                    d)\)\ n1\)\)\), 0, 0, 
        0, \(\((1 - d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\
\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\(\((d\ \
n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \
\(\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ \
n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + \
e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + e1)\)\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(-\(\(\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + 
                    d)\)\ n1\)\)\), 0, 0, 
        0, \(\((1 - d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\
\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\(\((d\ \
n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \
\(d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - \
e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\
\ \((1 - e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + e1)\)\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) + e1)\)\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 \
- e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-n2\) + d\ n2)\)\^2, \(\((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + e1)\)\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\
\/n1, 0, 0, 
        0, \(d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\
\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((\(-d\)\ n1 + \
\((\(-1\) + d)\)\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \(\
\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\)\ \((1 - e1)\) + e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-d\)\ n1 - n2 \
+ d\ n2)\)\^2}, {0, 0, 
        0, \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - \
e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \
\((\(-1\) + n2)\)\ n2\)\/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2)\)\^2, \
\(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + \
e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((n1 - d\ n1)\)\^2, 0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\
\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\((n1 - d\ n1 + d\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(-\(\(\
\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) \
- e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) + e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 0, 
        0, \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
                    e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + d)\)\ n1\)\)\), 
        0, 0, 0, \(\((1 - d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ \
n2)\)\), \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\
\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 \
- b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ n1\ n2\)\/\(\((d\ n1 - \
\((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) \
- e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) + e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\
\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + \
e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + 
                    e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + d)\)\ n1\)\)\), 
        0, 0, 0, \(\((1 - d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ \
n2)\)\), \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ \
n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((\(-1\) + d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) \
+ e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\
\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) + \
e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \
\((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) + e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-n2\) + d\ n2)\)\^2, \(\((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - e1)\)\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n1)\)\)\
\/n1, 0, 0, 
        0, \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((\(-d\)\ n1 + \
\((\(-1\) + d)\)\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\
\)\ n2\)\ \((1 - e2)\) + 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \(\
\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\)\ \((1 - e1)\) - e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) + e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-d\)\ n1 - n2 \
+ d\ n2)\)\^2}, {0, 0, 
        0, \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - e1)\) - \
e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - \
e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2)\
\)\^2, \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((n1 - d\ n1)\)\^2, 0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\
\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\
\((n1 - d\ n1 + d\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(-\(\(\
\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2\)\), \(d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) \
- e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((n1 - d\ n1 + d\ n2)\)\^2}, {0, 
        0, 0, \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + 
                    d)\)\ n1\)\)\), 0, 0, 
        0, \(\((1 - d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ \
n2)\)\), \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\
\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \
\((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) \
- e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\)\/\(\((\(-1\) + 
                    d)\)\ n2\)\)\), \(-\(\(\((1 - 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - 
                          e2)\) - e2)\)\ \((\(-1\) + n1)\)\)\/\(\((\(-1\) + 
                    d)\)\ n1\)\)\), 0, 0, 
        0, \(\((1 - d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ \
n1 - b\ \((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ \
n1\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ \
n2)\)\), \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\
\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - \
d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ \
n2)\)\ \((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((\(-1\) + d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\
\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ n1\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\), \(\((1 - d)\)\ d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\)\ \((1 - e1)\) - e1)\)\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 - d)\)\ n2\)\ \((1 - \
e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\(\((d\ n1 - \((\(-1\) + d)\)\ n2)\)\ \
\((\(-\((\(-1\) + d)\)\)\ n1 + d\ n2)\)\)}, {0, 0, 
        0, \(\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\)\ \
\((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-n2\) + d\ n2)\)\^2, \
\(\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - e1)\)\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + \
n1)\)\)\/n1, 0, 0, 
        0, \(d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n1)\)\ n1\)\/\((\(-d\)\ n1 + \
\((\(-1\) + d)\)\ n2)\)\^2, \(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \
\(-\(\(\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \((1 \
- d)\)\ n2\)\ \((1 - e2)\) - 
                    e2)\)\ n1\ n2\)\/\((\(-d\)\ n1 - n2 + d\ n2)\)\^2\)\), \(\
\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\)\ \((1 - e1)\) - e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1 - b\ \
\((1 - d)\)\ n2\)\ \((1 - e2)\) - e2)\)\ \((\(-1\) + n2)\)\ n2\)\/\((\(-d\)\ \
n1 - n2 + d\ n2)\)\^2}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpomThreePop", "Subsection"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nd = 3;\)\)\)], "Input"],

Cell[BoxData[
    \(m\_\(i, j\) == \((\((\((KroneckerDelta[i, 
                      j] \((1 - d)\) + \((1 - 
                        KroneckerDelta[i, 
                          j])\) \((d\ \[CapitalLambda]\_\(i, j\))\))\))\) \
\((1 - KroneckerDelta[po\_j])\) 
            b\ n\_j)\)/\((\[Sum]\+\(j = 1\)\%nd\((\((KroneckerDelta[i, 
                        j] \((1 - d)\) + \((1 - 
                          KroneckerDelta[i, 
                            j])\) \((d\ \[CapitalLambda]\_\(i, j\))\))\))\) \
\((1 - KroneckerDelta[po\_j])\) b\ n\_j)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\((F = \((Table[\((\((\((KroneckerDelta[i, 
                                j] \((1 - d)\) + \((1 - 
                                  KroneckerDelta[i, 
                                    j])\) \((d\ \[CapitalLambda]\_\(i, \
j\))\))\))\) \((1 - KroneckerDelta[po\_j])\) 
                      b\ n\_j)\)/\((\[Sum]\+\(j = 1\)\%nd\((\((KroneckerDelta[
                                  i, j] \((1 - d)\) + \((1 - 
                                    KroneckerDelta[i, 
                                      j])\) \((d\ \[CapitalLambda]\_\(i, j\))\
\))\))\) \((1 - KroneckerDelta[po\_j])\) b\ n\_j)\), {i, 1, nd}, {j, 1, 
                  nd}] /. {n\_1 \[Rule] n1, n\_2 \[Rule] n2, 
                n\_3 \[Rule] 
                  n3, \[CapitalLambda]\_\(1, 3\) \[Rule] \[CapitalLambda]13, \
\[CapitalLambda]\_\(2, 3\) \[Rule] 
                  1 - \[CapitalLambda]13, \[CapitalLambda]\_\(1, 2\) \[Rule] \
\[CapitalLambda]12, \[CapitalLambda]\_\(3, 2\) \[Rule] 
                  1 - \[CapitalLambda]12, \[CapitalLambda]\_\(2, 1\) \[Rule] \
\[CapitalLambda]21, \[CapitalLambda]\_\(3, 1\) \[Rule] 
                  1 - \[CapitalLambda]21})\))\) // MatrixForm\)\)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(b\ \((1 - d)\)\ n1\ \((1 - 
                        KroneckerDelta[po\_1])\)\)\/\(b\ \((1 - 
                          d)\)\ n1\ \((1 - KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \[CapitalLambda]12\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \[CapitalLambda]13\ \((1 - 
                          KroneckerDelta[
                            po\_3])\)\)\), \(\(b\ d\ n2\ \[CapitalLambda]12\ \
\((1 - KroneckerDelta[po\_2])\)\)\/\(b\ \((1 - d)\)\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \[CapitalLambda]12\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \[CapitalLambda]13\ \((1 - 
                          KroneckerDelta[
                            po\_3])\)\)\), \(\(b\ d\ n3\ \[CapitalLambda]13\ \
\((1 - KroneckerDelta[po\_3])\)\)\/\(b\ \((1 - d)\)\ n1\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \[CapitalLambda]12\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \[CapitalLambda]13\ \((1 - 
                          KroneckerDelta[po\_3])\)\)\)},
            {\(\(b\ d\ n1\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[
                          po\_1])\)\)\/\(b\ d\ n1\ \[CapitalLambda]21\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    b\ \((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - 
                          KroneckerDelta[po\_3])\)\)\), \(\(b\ \((1 - 
                        d)\)\ n2\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(b\ d\ n1\ \[CapitalLambda]21\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    b\ \((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - 
                          KroneckerDelta[
                            po\_3])\)\)\), \(\(b\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(b\ d\ n1\ \[CapitalLambda]21\ \((1 - 
                          KroneckerDelta[po\_1])\) + 
                    b\ \((1 - d)\)\ n2\ \((1 - KroneckerDelta[po\_2])\) + 
                    b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - 
                          KroneckerDelta[po\_3])\)\)\)},
            {\(\(b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - 
                        KroneckerDelta[
                          po\_1])\)\)\/\(b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\ \((1 - KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ \((1 - d)\)\ n3\ \((1 - 
                          KroneckerDelta[
                            po\_3])\)\)\), \(\(b\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\ \((1 - KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ \((1 - d)\)\ n3\ \((1 - 
                          KroneckerDelta[po\_3])\)\)\), \(\(b\ \((1 - 
                        d)\)\ n3\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\ \((1 - KroneckerDelta[po\_1])\) + 
                    b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - 
                          KroneckerDelta[po\_2])\) + 
                    b\ \((1 - d)\)\ n3\ \((1 - KroneckerDelta[po\_3])\)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Diag = \((DiagonalMatrix[
                Flatten[
                  ReplacePart[
                    Table[ReplacePart[Table[0, {i, 1, nd + 1}], 1\/n\_i, 
                        1], {i, 1, nd}], 1\/n\_nd, nd]]] /. {n\_1 \[Rule] n1, 
                n\_2 \[Rule] n2, n\_3 \[Rule] n3})\))\) // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/n1\), "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", \(1\/n2\), "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", \(1\/n3\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((G = 
          KroneckerProduct[F, F] - \((KroneckerProduct[F, F] . Diag)\) // 
            Simplify)\) // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\((\(-1\) + d)\)\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ KroneckerDelta[po\_1] - d\ n2\ \
\[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_3])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\)\), \(\(d\^2\ \((\(-1\) \
+ n2)\)\ n2\ \[CapitalLambda]12\^2\ \((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\
\/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\
\(-1\) + d)\)\ n1\ KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ \
KroneckerDelta[po\_2] - d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13\ \((\(-1\) + KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_3])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\)\), \(\(d\^2\ n2\ n3\ \
\[CapitalLambda]12\ \[CapitalLambda]13\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ \
KroneckerDelta[po\_1] - d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ \
n3\ \[CapitalLambda]13\ KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ \((\(-1\) + 
                        n3)\)\ n3\ \[CapitalLambda]13\^2\ \((\(-1\) + \
KroneckerDelta[po\_3])\)\^2\)\/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13 + \((\(-1\) + d)\)\ n1\ KroneckerDelta[po\_1] - d\ n2\ \
\[CapitalLambda]12\ KroneckerDelta[po\_2] - d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)},
            {\(\(\((\(-1\) + d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \[CapitalLambda]21\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\(\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(\((\(-1\) + d)\)\^2\ n1\ n2\
\ \((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\)\/\(\((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                          d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                          d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(d\^2\ n1\ n2\ \
\[CapitalLambda]12\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \[CapitalLambda]21\ \
\((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) - 
                        d\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ \((\(-1\) + 
                        n2)\)\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\(\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ n2\ n3\ \
\[CapitalLambda]12\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ n1\ n3\ \
\[CapitalLambda]13\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((\(-d\)\ n1\ \[CapitalLambda]21\ \
\((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) - 
                        d\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ \((\(-1\) + 
                        n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13\ \((\(-1\) + KroneckerDelta[po\_3])\)\^2\)\/\(\((n1 - 
                        d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\)},
            {\(\(\((\(-1\) + d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\
\) + KroneckerDelta[po\_1])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                        d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\)\/\(\((d\ n1 + d\ n2 + n3 - 
                        d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(\((\(-1\) + d)\)\^2\ n1\ n3\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + n3 - 
                        d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(d\^2\ n1\ n2\ \
\[CapitalLambda]12\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(d\^2\ \((\(-1\) + 
                          
                          n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12\ \((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\/\(\((d\ n1 + 
                          d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(d\^2\ n1\ n3\ \
\[CapitalLambda]13\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(d\^2\ n2\ n3\ \((\(-1\) \
+ \[CapitalLambda]12)\)\ \[CapitalLambda]13\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n3)\)\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
KroneckerDelta[po\_3])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\)},
            {\(\(\((\(-1\) + d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \[CapitalLambda]21\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\(\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ n1\ n2\ \
\[CapitalLambda]12\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((\(-d\)\ n1\ \[CapitalLambda]21\ \
\((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) - 
                        d\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(d\^2\ n1\ n3\ \
\[CapitalLambda]13\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((\(-d\)\ n1\ \[CapitalLambda]21\ \
\((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\ \((\((\(-1\) + 
                              d)\)\ n1\ \((\(-1\) + 
                              KroneckerDelta[po\_1])\) - 
                        d\ n2\ \[CapitalLambda]12\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) - 
                        d\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(-\(\(\((\(-1\) + d)\)\^2\ \
n1\ n2\ \((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\)\/\(\((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                          d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ \((\(-1\) + 
                        n2)\)\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\(\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \[CapitalLambda]13\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                          d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(d\^2\ n2\ n3\ \
\[CapitalLambda]12\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ \((\(-1\) + 
                        n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13\ \((\(-1\) + KroneckerDelta[po\_3])\)\^2\)\/\(\((n1 - 
                        d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                        d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\)},
            {\(\(d\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \[CapitalLambda]21\^2\ \((\(-1\) + \
KroneckerDelta[po\_1])\)\^2\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n2\ \[CapitalLambda]21\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)\), \(-\(\(d\^2\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\)\ \[CapitalLambda]21\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_3])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n1\ n2\ \[CapitalLambda]21\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_2])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)\), \(\(\((\(-1\) + d)\)\^2\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \
KroneckerDelta[po\_2])\)\^2\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(-\(\(d\^2\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\)\ \[CapitalLambda]21\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[
                            po\_3])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ \((\(-1\) + 
                        n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2\ \
\((\(-1\) + KroneckerDelta[po\_3])\)\^2\)\/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21 - d\ n1\ \[CapitalLambda]21\ \
KroneckerDelta[po\_1] + \((\(-1\) + d)\)\ n2\ KroneckerDelta[po\_2] - d\ n3\ \
KroneckerDelta[po\_3] + d\ n3\ \[CapitalLambda]13\ \
KroneckerDelta[po\_3])\)\^2\)},
            {\(\(d\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\)\^2\)\/\(\((d\ n1 + 
                        d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + d\ n2 - 
                        d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(d\^2\ n1\ n2\ \((1 - \
\[CapitalLambda]12)\)\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\)\), \(\(\((1 - 
                        d)\)\ d\ n1\ n3\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\)\), \(\(\((1 - 
                        d)\)\ d\ n1\ n2\ \((1 - \[CapitalLambda]21)\)\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + 
                          d\ n2 - d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(\((b - b\ d)\)\^2\ n2\ n3\ \
\((1 - KroneckerDelta[po\_2])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(b\^2\ \((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(d\^2\ n1\ n3\ \((1 - \
\[CapitalLambda]13)\)\ \((1 - \[CapitalLambda]21)\)\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(d\^2\ n2\ n3\ \((1 - \
\[CapitalLambda]12)\)\ \((1 - \[CapitalLambda]13)\)\ \((1 - 
                        KroneckerDelta[po\_2])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_3])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + 
                          d\ n2 - d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\)},
            {\(\(\((\(-1\) + d)\)\ d\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\
\) + KroneckerDelta[po\_1])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                        d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(d\^2\ n1\ n2\ \
\[CapitalLambda]12\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(d\^2\ n1\ n3\ \
\[CapitalLambda]13\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                          KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(\((\(-1\) + 
                        d)\)\ d\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_2])\)\)\/\(\((d\ n1 + d\ n2 + n3 - 
                        d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(d\^2\ \((\(-1\) + 
                          n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12\ \((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\/\(\((d\ n1 + 
                          d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(d\^2\ n2\ n3\ \((\(-1\) \
+ \[CapitalLambda]12)\)\ \[CapitalLambda]13\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(\((\(-1\) + d)\)\^2\ n1\ \
n3\ \((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + n3 - 
                        d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                        d\ n2\ \[CapitalLambda]12 + 
                        d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                              d)\)\ n1\ KroneckerDelta[po\_1] - 
                        d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + 
                          KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                          KroneckerDelta[po\_3])\)\)\/\(\((d\ n1 + d\ n2 + 
                          n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n3)\)\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
KroneckerDelta[po\_3])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((n1 - d\ n1 + 
                          d\ n2\ \[CapitalLambda]12 + 
                          d\ n3\ \[CapitalLambda]13 + \((\(-1\) + 
                                d)\)\ n1\ KroneckerDelta[po\_1] - 
                          d\ n2\ \[CapitalLambda]12\ KroneckerDelta[po\_2] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\)},
            {\(\(d\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\)\^2\)\/\(\((d\ n1 + 
                        d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                        d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + d\ n2 - 
                        d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                        d\ n1\ \[CapitalLambda]21 + 
                        d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                            po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                            po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                        d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                            po\_3])\)\)\), \(\(\((1 - 
                        d)\)\ d\ n1\ n2\ \((1 - \[CapitalLambda]21)\)\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(d\^2\ n1\ n3\ \((1 - \
\[CapitalLambda]13)\)\ \((1 - \[CapitalLambda]21)\)\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(d\^2\ n1\ n2\ \((1 - \
\[CapitalLambda]12)\)\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_2])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + 
                          d\ n2 - d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\), \(\(d\^2\ n2\ n3\ \((1 - \
\[CapitalLambda]12)\)\ \((1 - \[CapitalLambda]13)\)\ \((1 - 
                        KroneckerDelta[po\_2])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_3])\))\)\)\), \(\(\((1 - 
                        d)\)\ d\ n1\ n3\ \[CapitalLambda]21\ \((1 - 
                        KroneckerDelta[po\_1])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(\((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(\(\((b - b\ d)\)\^2\ n2\ \
n3\ \((1 - KroneckerDelta[po\_2])\)\ \((1 - 
                        KroneckerDelta[
                          po\_3])\)\)\/\(b\^2\ \((d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ \((\(-1\) + KroneckerDelta[po\_1])\) + 
                        d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + \((\(-1\) + 
                              d)\)\ n3\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\ \((\(-d\)\ n1\ \
\[CapitalLambda]21\ \((\(-1\) + KroneckerDelta[po\_1])\) + \((\(-1\) + 
                              d)\)\ n2\ \((\(-1\) + 
                              KroneckerDelta[po\_2])\) + 
                        d\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \((\(-1\) + 
                              KroneckerDelta[
                                po\_3])\))\)\)\), \(-\(\(\((\(-1\) + 
                          d)\)\ d\ \((\(-1\) + 
                          n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\((\(-1\) + KroneckerDelta[po\_3])\)\^2\)\/\(\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                          d\ n2\ \[CapitalLambda]12 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
KroneckerDelta[po\_1] + 
                          d\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + 
                          d\ n3\ KroneckerDelta[po\_3])\)\ \((\(-n2\) + 
                          d\ n2 - d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                          d\ n1\ \[CapitalLambda]21 + 
                          d\ n1\ \[CapitalLambda]21\ KroneckerDelta[
                              po\_1] + \((n2 - d\ n2)\)\ KroneckerDelta[
                              po\_2] + d\ n3\ KroneckerDelta[po\_3] - 
                          d\ n3\ \[CapitalLambda]13\ KroneckerDelta[
                              po\_3])\)\)\)\)},
            {\(\(d\^2\ \((\(-1\) + 
                        n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\^2\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ \
n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                        KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_2])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + 
                        d)\)\ d\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ \((\(-1\) + \[CapitalLambda]21)\)\ \((\(-1\) + 
                        KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_2])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(d\^2\ \((\(-1\) + 
                        n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\^2\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ \
n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + 
                        d)\)\ d\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\((\(-1\) + KroneckerDelta[po\_1])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + 
                        d)\)\ d\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\((\(-1\) + KroneckerDelta[po\_2])\)\ \((\(-1\) + 
                        KroneckerDelta[
                          po\_3])\)\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\), \(\(\((\(-1\) + d)\)\^2\ \((\(-1\) + 
                        n3)\)\ n3\ \((\(-1\) + \
KroneckerDelta[po\_3])\)\^2\)\/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\)\ KroneckerDelta[po\_1] + d\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\)\ KroneckerDelta[po\_2] - n3\ KroneckerDelta[po\_3] + d\ \
n3\ KroneckerDelta[po\_3])\)\^2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
      Delete[Transpose[
          Delete[\((Partition[
                Flatten[
                  Table[Flatten[
                      Table[Table[\((\((\((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1\ \((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \
\[CapitalLambda]12\ \((1 - KroneckerDelta[po\_2])\) - b\ d\ n3\ \
\[CapitalLambda]13\ \((1 - KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) - e1)\)\^\
\(1 - KroneckerDelta[do\_1]\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\ \
\((1 - KroneckerDelta[po\_1])\) - b\ d\ n2\ \[CapitalLambda]12\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \[CapitalLambda]13\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e1)\) + e1)\)\^KroneckerDelta[do\_1]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) - e2)\)\^\(1 - KroneckerDelta[do\_2]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \[CapitalLambda]21\ \((1 - \
KroneckerDelta[po\_1])\) - b\ \((1 - d)\)\ n2\ \((1 - \
KroneckerDelta[po\_2])\) - b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e2)\) + e2)\)\^KroneckerDelta[do\_2]\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) - e3)\)\^\(1 - KroneckerDelta[do\_3]\
\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \[CapitalLambda]21)\)\ \((1 - \
KroneckerDelta[po\_1])\) - b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
KroneckerDelta[po\_2])\) - b\ \((1 - d)\)\ n3\ \((1 - \
KroneckerDelta[po\_3])\)\)\ \((1 - e3)\) + e3)\)\^KroneckerDelta[do\_3])\) 
                              G\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\), {po\_1, 0, 1}, {po\_2, 0, 1}, {po\_3, 0, 
                            1}], {i, 1, nd\^2}]], {do\_1, 0, 1}, {do\_2, 0, 
                      1}, {do\_3, 0, 1}]], \(nd\^2\) 2\^nd])\), 
            Table[{i}, {i, 1, nd\^2}]]], 
        Table[{i}, {i, 1, nd\^2}]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"indet\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(\\(0\\\\ \\(\\((\\(\\(-1\\)\\) + d)\\)\\)\\\\ d\\\\ \
\\(\\((\\(\\(-1\\)\\) + n1)\\)\\)\\\\ n1\\\\ \[CapitalLambda]21\\\\ \
ComplexInfinity\\)\\/\\(n1 + \\(\\(\\(\\((\\(\\(-1\\)\\) + d)\\)\\)\\\\ n1\\)\
\\) - \\(\\(d\\\\ n1\\)\\)\\)\\) encountered. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(\\(0\\\\ \\((\\(\\(-1\\)\\) + d)\\)\\^2\\\\ n1\\\\ n2\\\\ \
ComplexInfinity\\)\\/\\(n1 + \\(\\(\\(\\((\\(\\(-1\\)\\) + d)\\)\\)\\\\ n1\\)\
\\) - \\(\\(d\\\\ n1\\)\\)\\)\\) encountered. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"infy\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(\\(0\\\\ \\(\\((\\(\\(-1\\)\\) + d)\\)\\)\\\\ d\\\\ n1\\\\ \
n3\\\\ \\(\\((\\(\\(-1\\)\\) + \[CapitalLambda]13)\\)\\)\\\\ \
ComplexInfinity\\)\\/\\(n1 + \\(\\(\\(\\((\\(\\(-1\\)\\) + d)\\)\\)\\\\ n1\\)\
\\) - \\(\\(d\\\\ n1\\)\\)\\)\\) encountered. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(\[Infinity] :: \\\"indet\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\
\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 \
- e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 \
- e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \[CapitalLambda]13\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\
\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\
\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((\
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \
\((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) + 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\
\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(\((\(-1\) + 
                    d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\
\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\)\/\(n1 - 
                d\ n1\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\
\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \((1 \
- e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\ \
n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                    
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                          e2)\) + 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ d\
\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - 
                        e2)\) + 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\ \
n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\
\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) + e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ d\
\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\
\ \((1 - e3)\) + e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 + \((\(-1\) + \
d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(\(1\/\((n1 - d\ n1)\)\^2\)\((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\)\ n1)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((\((\(-1\
\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 0, 0, 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n3\ \
\[CapitalLambda]13)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13)\)\)\), 
        0, \(\(1\/\((n1 - d\ n1 + d\ n3\ \[CapitalLambda]13)\)\^2\)\((d\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - b\ \
d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                n3)\)\ n3\ \[CapitalLambda]13\^2)\)\), \(\(1\/\((n1 - d\ n1 + \
d\ n2\ \[CapitalLambda]12)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1)\)\), \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), 
        0, \(-\(\(1\/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12)\)\)\), \(\(1\/\((n1 - d\ \
n1 + d\ n2\ \[CapitalLambda]12)\)\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\
\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n2)\)\ n2\ \[CapitalLambda]12\^2)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ \
n3\ \[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \(-\(\((\((\(-1\
\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ \
n2\ \[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \
\[CapitalLambda]13)\)/\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + d\ n3\ \
\[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \[CapitalLambda]13\^2)\)/\((n1 - d\ n1 + d\ n2\ \
\[CapitalLambda]12 + d\ n3\ \[CapitalLambda]13)\)\^2}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + d)\)\^2\ \
\((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + 
                  d\ n2)\)\ \((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((\(-n2\) + 
                  d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((n1 + \((\(-1\) + 
                        d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\))\), \(-\(\(1\/\(n1 - 
                d\ n1\)\)\((\((\(-1\) + 
                  d)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n1)\))\)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \
\((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]12\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]13\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-\((\(-1\) + 
                          d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ n1\ n2)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\)}, {0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 0, 0, 
        0, 0, \(\(1\/\((n2 - d\ n2)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 
        0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 + \((\(-1\) + \
d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 + \((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 + \
\((\(-1\) + d)\)\ n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \
\[CapitalLambda]21)\)\^2, \(\(1\/\((n2 - d\ n2 + d\ n1\ \[CapitalLambda]21)\)\
\^2\)\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + 
                n1)\)\ n1\ \[CapitalLambda]21\^2)\)\), \(-\(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), 
        0, \(-\(\(1\/\((n2 - d\ n2 + d\ n1\ \
\[CapitalLambda]21)\)\^2\)\((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \[CapitalLambda]21)\)\)\), \(\(1\/\((n2 - d\ \
n2 + d\ n1\ \[CapitalLambda]21)\)\^2\)\((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - b\ \
d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                      e3)\) - e3)\)\ \((\(-1\) + n2)\)\ n2)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \[CapitalLambda]21\^2)\)/\((n2 - d\ n2 + d\ n3 - \
d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ \
n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2\)\), \
\((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\
\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \
\[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\ \
\[CapitalLambda]21)\)/\((n2 - d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ \
n1\ \[CapitalLambda]21)\)\^2\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\)\^2)\)/\((n2 - \
d\ n2 + d\ n3 - d\ n3\ \[CapitalLambda]13 + d\ n1\ \[CapitalLambda]21)\)\^2}, \
{0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((b - b\ d)\)\^2\
\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + d)\)\ n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 + \((\(-1\) \
+ d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 + \((\(-1\) + 
                          d)\)\ n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1)\)\ \((d\ n1 + d\ n2 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 0, 0, 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + 
                  n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((\((n1 - 
                  d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n2\ \[CapitalLambda]12\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n1\ n3\ \[CapitalLambda]13\ \((\(-1\) + \
\[CapitalLambda]21)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]12)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\)\ \
\[CapitalLambda]13)\)/\((\((n1 - d\ n1 + d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n1\ n3)\)/\((\((n1 - d\ n1 + 
                  d\ n2\ \[CapitalLambda]12 + 
                  d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                  d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                    e3)\)\ n2\ n3\ \[CapitalLambda]12)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \[CapitalLambda]13)\)/\((\((n1 - d\ n1 + 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n3\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n2\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 0, 0, 0, 0, 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \
\[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), 
        0, \((\((b - b\ d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - 
                  d\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\))\), \(-\(\((\((\
\(-1\) + d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \
\[CapitalLambda]13)\))\)/\((\((\(-n2\) + d\ n2 - d\ n3 + 
                    d\ n3\ \[CapitalLambda]13)\)\ \((d\ n1 + d\ n2 + n3 - 
                    d\ n3 - d\ n2\ \[CapitalLambda]12 + 
                    d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \(-\(\((d\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n1)\)\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ n1 + 
                d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\)\), 
        0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 + 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 0, 0, 
        0, \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \((\(-d\)\ n3\ \
\((\(-1\) + \[CapitalLambda]13)\) + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-d\)\ n3 + 
                    d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((\(-n2\) + d\ n2 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-d\)\
\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + d\ n1\ \[CapitalLambda]21)\))\), 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-d\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                          e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \
\[CapitalLambda]12)\))\)/\((\((\(-n2\) + d\ n2 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((d\ n1 + d\ n2 - 
                    d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\ \
\[CapitalLambda]21)\)/\((\((d\ n1 + d\ n2 + n3 - d\ n3 - 
                  d\ n2\ \[CapitalLambda]12 - 
                  d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - d\ n3 + 
                  d\ n3\ \[CapitalLambda]13 - 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]21)\))\)/\((\((\(-\((\
\(-1\) + d)\)\)\ n3 - d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((1 - \[CapitalLambda]13)\)\ \((1 - \
\[CapitalLambda]21)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((1 - \[CapitalLambda]12)\)\ \
\[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\), \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((1 - \[CapitalLambda]12)\)\ \((1 - \
\[CapitalLambda]13)\))\)/\((\((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((1 - 
                  
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \[CapitalLambda]21)\)/\((\((\(-\((\(-1\) + 
                          d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \((\((b - b\ d)\)\^2\ \((1 \
- \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - \
b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ n2\ n3)\)/\((b\^2\ \((\(-\((\(-1\) + d)\)\)\ n3 - 
                  d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - 
                  d\ n1\ \((\(-1\) + \[CapitalLambda]21)\))\)\ \
\((\(-\((\(-1\) + d)\)\)\ n2 - d\ n3\ \((\(-1\) + \[CapitalLambda]13)\) + 
                  d\ n1\ \[CapitalLambda]21)\))\), \(-\(\((\((\(-1\) + 
                    d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ \
n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                          e1)\) - 
                    e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 \
- b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \
\((1 - e2)\) - 
                    e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 \
- b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                    n3)\)\ n3\ \((\(-1\) + \[CapitalLambda]13)\))\)/\((\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - 
                    d\ n1\ \[CapitalLambda]21)\)\ \((\(-n2\) + d\ n2 - 
                    d\ n3 + d\ n3\ \[CapitalLambda]13 - 
                    d\ n1\ \[CapitalLambda]21)\))\)\)\)}, {0, 0, 0, 0, 0, 0, 
        0, 0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\
\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3\)\ \
\((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2\)\ \
\((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 + d\ n1\ \((\(-1\) + \
\[CapitalLambda]21)\) - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + \
d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \[CapitalLambda]12 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\)\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 + d\ n1\ \((\(-1\) + \[CapitalLambda]21)\) - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \
\[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n1\ \((1 - \
\[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 0, 0, 0, 0, 0, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\) + \[CapitalLambda]12)\) - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 
        0, \((\((\(-1\) + d)\)\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n3\ \((1 - \
\[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 + d\ n2\ \((\(-1\
\) + \[CapitalLambda]12)\) - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \
\((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, 
        0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ \
n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ \
n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 \
- d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n1\ \[CapitalLambda]21\)\ \((1 - e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ d\ n2\ \((1 - \
\[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\)\)\ \((1 - 
                        e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, 0, 0, 
        0, 0, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ \
d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n1)\)\ n1\ \((\(-1\) + \[CapitalLambda]21)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \
\[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - \
d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \
\((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\ \((\(-1\) \
+ \[CapitalLambda]21)\))\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2, \((d\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n2)\)\ n2\ \((\(-1\) + \[CapitalLambda]12)\)\^2)\)/\((d\ n1 \
+ d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\
\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n1\ n3\ \((\(-1\) + \[CapitalLambda]21)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + 
                  d)\)\ d\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 \
- b\ d\ n2\ \[CapitalLambda]12 - b\ d\ n3\ \[CapitalLambda]13\)\ \((1 - 
                        e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - 
                  e3)\)\ n2\ n3\ \((\(-1\) + \[CapitalLambda]12)\))\)/\((d\ \
n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \[CapitalLambda]12 - d\ n1\ \
\[CapitalLambda]21)\)\^2, \((\((\(-1\) + d)\)\^2\ \((1 - \
\[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n1 - b\ d\ n2\ \[CapitalLambda]12 - b\
\ d\ n3\ \[CapitalLambda]13\)\ \((1 - e1)\) - 
                  e1)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n2 - \
b\ d\ n3\ \((1 - \[CapitalLambda]13)\) - b\ d\ n1\ \[CapitalLambda]21\)\ \((1 \
- e2)\) - 
                  e2)\)\ \((1 - \[ExponentialE]\^\(\(-b\)\ \((1 - d)\)\ n3 - \
b\ d\ n2\ \((1 - \[CapitalLambda]12)\) - b\ d\ n1\ \((1 - \[CapitalLambda]21)\
\)\)\ \((1 - e3)\) - e3)\)\ \((\(-1\) + 
                  n3)\)\ n3)\)/\((d\ n1 + d\ n2 + n3 - d\ n3 - d\ n2\ \
\[CapitalLambda]12 - d\ n1\ \[CapitalLambda]21)\)\^2}}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Divers", "Section"],

Cell[CellGroupData[{

Cell["Indirect calculations of graphes twospom", "Subsubsection"],

Cell[BoxData[
    \(CalcEigenvalueTwoPom[b_, d_, e1_, e2_, e3_, n1_, n2_, n3_] := 
      Flatten[Module[{\[Lambda]Po, \[Lambda]T}, \[Lambda]Po = 
            Eigenvalues[TwPomPoMatrix[b, d, e1, e2, n1, n2], 1]; \[Lambda]T = 
            Eigenvalues[TwPomTMatrix[b, d, e1, e2, n1, n2], 
              1]; {\[Lambda]Po, \[Lambda]T, \[Lambda]T\/\[Lambda]Po}]]\)], \
"Input"],

Cell[BoxData[
    \(\[IndentingNewLine]\)], "Input"],

Cell[BoxData[
    \(dataTwo[Mesh_, b_, d_, e1_, e2_, n1_, n2_] := 
      Table[{m, CalcEigenvalueTwoPom[b, m, e1, e2, n1, n2]}, {m, 0.001, 
          1.001, Mesh}]\)], "Input"],

Cell[BoxData[
    \(\[IndentingNewLine]\)], "Input"],

Cell[BoxData[
    \(GrapheTwo[Mesh_, b_, d_, e1_, e2_, n1_, n2_] := 
      MultipleListPlot[
        Table[{\(\(dataTwo[Mesh, b, d, e1, e2, n1, n2]\)\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
            Part[\(\(dataTwo[Mesh, b, d, e1, e2, n1, \
n2]\)\[LeftDoubleBracket]i\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\
\(2\)\(\[RightDoubleBracket]\)\), 1]}, {i, 1, 1 + 1\/Mesh}], 
        Table[{\(\(dataTwo[Mesh, b, d, e1, e2, n1, n2]\)\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
            Part[\(\(dataTwo[Mesh, b, d, e1, e2, n1, \
n2]\)\[LeftDoubleBracket]i\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\
\(2\)\(\[RightDoubleBracket]\)\), 2]}, {i, 1, 1 + 1\/Mesh}], 
        Table[{\(\(dataTwo[Mesh, b, d, e1, e2, n1, n2]\)\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
            Part[\(\(dataTwo[Mesh, b, d, e1, e2, n1, \
n2]\)\[LeftDoubleBracket]i\[RightDoubleBracket]\)\_\(\(\[LeftDoubleBracket]\)\
\(2\)\(\[RightDoubleBracket]\)\), 3]}, {i, 1, 1 + 1\/Mesh}], 
        PlotJoined \[Rule] True, Frame \[Rule] True, 
        PlotRange \[Rule] {{0, 1}, {0, 1}}, Axes \[Rule] None, 
        SymbolShape \[Rule] {PlotSymbol[Box], PlotSymbol[Triangle], 
            PlotSymbol[Diamond]}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrapheTwo[0.1, 1.1, 0, 0.4, 0, 10, 10]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.0001 w
.001 .67984 -2.5 2.5 Mabsadd m
.001 .67984 2.5 2.5 Mabsadd L
.001 .67984 2.5 -2.5 Mabsadd L
.001 .67984 -2.5 -2.5 Mabsadd L
.001 .67984 -2.5 2.5 Mabsadd L closepath F
.101 .67984 -2.5 2.5 Mabsadd m
.101 .67984 2.5 2.5 Mabsadd L
.101 .67984 2.5 -2.5 Mabsadd L
.101 .67984 -2.5 -2.5 Mabsadd L
.101 .67984 -2.5 2.5 Mabsadd L closepath F
.201 .67984 -2.5 2.5 Mabsadd m
.201 .67984 2.5 2.5 Mabsadd L
.201 .67984 2.5 -2.5 Mabsadd L
.201 .67984 -2.5 -2.5 Mabsadd L
.201 .67984 -2.5 2.5 Mabsadd L closepath F
.301 .67984 -2.5 2.5 Mabsadd m
.301 .67984 2.5 2.5 Mabsadd L
.301 .67984 2.5 -2.5 Mabsadd L
.301 .67984 -2.5 -2.5 Mabsadd L
.301 .67984 -2.5 2.5 Mabsadd L closepath F
.401 .67984 -2.5 2.5 Mabsadd m
.401 .67984 2.5 2.5 Mabsadd L
.401 .67984 2.5 -2.5 Mabsadd L
.401 .67984 -2.5 -2.5 Mabsadd L
.401 .67984 -2.5 2.5 Mabsadd L closepath F
.501 .67984 -2.5 2.5 Mabsadd m
.501 .67984 2.5 2.5 Mabsadd L
.501 .67984 2.5 -2.5 Mabsadd L
.501 .67984 -2.5 -2.5 Mabsadd L
.501 .67984 -2.5 2.5 Mabsadd L closepath F
.601 .67984 -2.5 2.5 Mabsadd m
.601 .67984 2.5 2.5 Mabsadd L
.601 .67984 2.5 -2.5 Mabsadd L
.601 .67984 -2.5 -2.5 Mabsadd L
.601 .67984 -2.5 2.5 Mabsadd L closepath F
.701 .67984 -2.5 2.5 Mabsadd m
.701 .67984 2.5 2.5 Mabsadd L
.701 .67984 2.5 -2.5 Mabsadd L
.701 .67984 -2.5 -2.5 Mabsadd L
.701 .67984 -2.5 2.5 Mabsadd L closepath F
.801 .67984 -2.5 2.5 Mabsadd m
.801 .67984 2.5 2.5 Mabsadd L
.801 .67984 2.5 -2.5 Mabsadd L
.801 .67984 -2.5 -2.5 Mabsadd L
.801 .67984 -2.5 2.5 Mabsadd L closepath F
.901 .67984 -2.5 2.5 Mabsadd m
.901 .67984 2.5 2.5 Mabsadd L
.901 .67984 2.5 -2.5 Mabsadd L
.901 .67984 -2.5 -2.5 Mabsadd L
.901 .67984 -2.5 2.5 Mabsadd L closepath F
1.001 .67984 -2.5 2.5 Mabsadd m
1.001 .67984 2.5 2.5 Mabsadd L
1.001 .67984 2.5 -2.5 Mabsadd L
1.001 .67984 -2.5 -2.5 Mabsadd L
1.001 .67984 -2.5 2.5 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.001 .00062 m
.101 .06242 L
.201 .12422 L
.301 .18603 L
.401 .24783 L
.501 .30964 L
.601 .37144 L
.701 .43324 L
.801 .49505 L
.901 .55685 L
s
.901 .55685 m
1 .61803 L
s
.0001 w
[ ] 0 setdash
.001 .00062 0 2.5 Mabsadd m
.001 .00062 -2.165 -1.25 Mabsadd L
.001 .00062 2.165 -1.25 Mabsadd L
.001 .00062 0 2.5 Mabsadd L closepath F
.101 .06242 0 2.5 Mabsadd m
.101 .06242 -2.165 -1.25 Mabsadd L
.101 .06242 2.165 -1.25 Mabsadd L
.101 .06242 0 2.5 Mabsadd L closepath F
.201 .12422 0 2.5 Mabsadd m
.201 .12422 -2.165 -1.25 Mabsadd L
.201 .12422 2.165 -1.25 Mabsadd L
.201 .12422 0 2.5 Mabsadd L closepath F
.301 .18603 0 2.5 Mabsadd m
.301 .18603 -2.165 -1.25 Mabsadd L
.301 .18603 2.165 -1.25 Mabsadd L
.301 .18603 0 2.5 Mabsadd L closepath F
.401 .24783 0 2.5 Mabsadd m
.401 .24783 -2.165 -1.25 Mabsadd L
.401 .24783 2.165 -1.25 Mabsadd L
.401 .24783 0 2.5 Mabsadd L closepath F
.501 .30964 0 2.5 Mabsadd m
.501 .30964 -2.165 -1.25 Mabsadd L
.501 .30964 2.165 -1.25 Mabsadd L
.501 .30964 0 2.5 Mabsadd L closepath F
.601 .37144 0 2.5 Mabsadd m
.601 .37144 -2.165 -1.25 Mabsadd L
.601 .37144 2.165 -1.25 Mabsadd L
.601 .37144 0 2.5 Mabsadd L closepath F
.701 .43324 0 2.5 Mabsadd m
.701 .43324 -2.165 -1.25 Mabsadd L
.701 .43324 2.165 -1.25 Mabsadd L
.701 .43324 0 2.5 Mabsadd L closepath F
.801 .49505 0 2.5 Mabsadd m
.801 .49505 -2.165 -1.25 Mabsadd L
.801 .49505 2.165 -1.25 Mabsadd L
.801 .49505 0 2.5 Mabsadd L closepath F
.901 .55685 0 2.5 Mabsadd m
.901 .55685 -2.165 -1.25 Mabsadd L
.901 .55685 2.165 -1.25 Mabsadd L
.901 .55685 0 2.5 Mabsadd L closepath F
1.001 .61865 0 2.5 Mabsadd m
1.001 .61865 -2.165 -1.25 Mabsadd L
1.001 .61865 2.165 -1.25 Mabsadd L
1.001 .61865 0 2.5 Mabsadd L closepath F
.001 w
[ .5 4 5 4 ] 0 Mabsdash
.001 .24721 m
.101 .24721 L
.201 .24721 L
.301 .24721 L
.401 .24721 L
.501 .24721 L
.601 .24721 L
.701 .24721 L
.801 .24721 L
.901 .24721 L
s
.901 .24721 m
1 .24721 L
s
.0001 w
[ ] 0 setdash
.001 .24721 -1.875 0 Mabsadd m
.001 .24721 0 2.5 Mabsadd L
.001 .24721 1.875 0 Mabsadd L
.001 .24721 0 -2.5 Mabsadd L
.001 .24721 -1.875 0 Mabsadd L closepath F
.101 .24721 -1.875 0 Mabsadd m
.101 .24721 0 2.5 Mabsadd L
.101 .24721 1.875 0 Mabsadd L
.101 .24721 0 -2.5 Mabsadd L
.101 .24721 -1.875 0 Mabsadd L closepath F
.201 .24721 -1.875 0 Mabsadd m
.201 .24721 0 2.5 Mabsadd L
.201 .24721 1.875 0 Mabsadd L
.201 .24721 0 -2.5 Mabsadd L
.201 .24721 -1.875 0 Mabsadd L closepath F
.301 .24721 -1.875 0 Mabsadd m
.301 .24721 0 2.5 Mabsadd L
.301 .24721 1.875 0 Mabsadd L
.301 .24721 0 -2.5 Mabsadd L
.301 .24721 -1.875 0 Mabsadd L closepath F
.401 .24721 -1.875 0 Mabsadd m
.401 .24721 0 2.5 Mabsadd L
.401 .24721 1.875 0 Mabsadd L
.401 .24721 0 -2.5 Mabsadd L
.401 .24721 -1.875 0 Mabsadd L closepath F
.501 .24721 -1.875 0 Mabsadd m
.501 .24721 0 2.5 Mabsadd L
.501 .24721 1.875 0 Mabsadd L
.501 .24721 0 -2.5 Mabsadd L
.501 .24721 -1.875 0 Mabsadd L closepath F
.601 .24721 -1.875 0 Mabsadd m
.601 .24721 0 2.5 Mabsadd L
.601 .24721 1.875 0 Mabsadd L
.601 .24721 0 -2.5 Mabsadd L
.601 .24721 -1.875 0 Mabsadd L closepath F
.701 .24721 -1.875 0 Mabsadd m
.701 .24721 0 2.5 Mabsadd L
.701 .24721 1.875 0 Mabsadd L
.701 .24721 0 -2.5 Mabsadd L
.701 .24721 -1.875 0 Mabsadd L closepath F
.801 .24721 -1.875 0 Mabsadd m
.801 .24721 0 2.5 Mabsadd L
.801 .24721 1.875 0 Mabsadd L
.801 .24721 0 -2.5 Mabsadd L
.801 .24721 -1.875 0 Mabsadd L closepath F
.901 .24721 -1.875 0 Mabsadd m
.901 .24721 0 2.5 Mabsadd L
.901 .24721 1.875 0 Mabsadd L
.901 .24721 0 -2.5 Mabsadd L
.901 .24721 -1.875 0 Mabsadd L closepath F
1.001 .24721 -1.875 0 Mabsadd m
1.001 .24721 0 2.5 Mabsadd L
1.001 .24721 1.875 0 Mabsadd L
1.001 .24721 0 -2.5 Mabsadd L
1.001 .24721 -1.875 0 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Uooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00009Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000[ooooo`?o00001Oooool0
04;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000009?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool00000:oooool00ol0003oooooooooo`04ooooo`00@_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001oooool5o`0002Cooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Cooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01?oo
ool004;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Sooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00009Oooool01?l0003oooooooooool00007oooo
o`Co00009Oooool01?l0003oooooooooool00008ooooo`?o0000;?ooool00ol0003oooooooooo`04
ooooo`00@_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002Gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03o`000?oooooooooo00Cooooo0012ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Tooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Uooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000:_ooool2o`0000Kooooo0013oooo
o`;o00002Oooool3o`0002Kooooo0_l0000;ooooo`03o`000?oooooooooo02Cooooo0_l0000:oooo
o`;o00009_ooool2o`0000Wooooo0ol0000/ooooo`03o`000?oooooooooo00Cooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Goooooooo00001Ol00005oooo
o`005oooool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`00
5oooool01?l0003oooooooooool0003oooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`00
0?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?[ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000
ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`03ooooo`005oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`3cooooo`;o00001Oooool001Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`3aooooo`03o`000?oooooooooo00?ooooo000G
ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0joooool00ol0003oooooooooo`03ooooo`005ooo
ool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`3Xooooo`03o`000?oooooooooo00?ooooo000Goooo
o`03o`000?oooooooooo01Gooooo1?l0003Vooooo`;o00001Oooool001Oooooo00?o0000oooooooo
ool05_ooool3o`000>Oooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo00000>Cooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo00?ooooo
000Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0goooool00ol0003ooooooooo
o`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool0
01Oooooo00?o0000ooooooooool08?ooool2o`000=kooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`00
0?oooooooooo02?ooooo0_l0003Jooooo`;o00001Oooool001Oooooo00?o0000ooooooooool0oooo
ool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo02Kooooo0_l0003H
ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Yooooo`;o0000eOooool00ol0003o
ooooooooo`03ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00005ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`03ooooo`00
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo0<kooooo00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`04ooooo`;o0000<?ooool4o`000<_ooooo0ol00005oooo
o`000_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`0`ooooo`Co0000c?ooool00ol0003oooooooooo`03ooooo`000_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool00oooool000?ooooo0_l00009
ooooo`?o00001_ooool00ol0003oooooooooo`0eooooo`;o0000bOooool00ol0003oooooooooo`03
ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0>?ooool2o`000<Kooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oo
oooooooo03_ooooo0_l00033ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0__ooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00?ooooo
000Gooooo`03o`000?oooooooooo04Cooooo0_l0002jooooo`03o`000?oooooooooo00?ooooo000G
ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0
003oooooooooo`17ooooo`;o0000]oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003o
ooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0
B?ooool5o`000;;ooooo0_l00005ooooo`005oooool00ol0003oooooooooo`19ooooo`Co0000/ooo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`1:ooooo`;o000000?ooooo
o`000?l00000/Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooooooo
ool0D?ooool2o`000:kooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`005oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool00oooool0
01Oooooo00?o0000ooooooooool0ooooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooo
ooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooo
oooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`000oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool3o`0000Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool000;o
oooo00Co0000oooooooooooo00001oooool5o`0000Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooo`00000Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`03ooooo`000_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Kooooo0_l00002ooooo`Ko00000oooool2o`0000?ooooo1_l000001?oooooo0000o`000?l0
0003ooooo`Ko00000oooool2o`0000?ooooo2?l000000ooooooo0000ooooo`02ooooo`Ko00000ooo
ool2o`0000?ooooo1ol00002ooooo`04o`000?ooooooooooooooo`Ko00000oooool2o`0000?ooooo
1ol00002ooooo`04o`000?ooooooooooooooo`Ko00000oooool2o`0000?ooooo1_l00003ooooo`04
o`000?ooooooooooooooo`Ko00000oooool2o`0000?ooooo1_l00003ooooo`04o`000?oooooooooo
ooooo`Ko00000oooool2o`0000?ooooo1_l00003ooooo`04o`000?ooooooooooooooo`Ko00000ooo
ool2o`0000;ooooo1ol00003ooooo`04o`000?ooooooooooooooo`Ko00000oooool2o`000004oooo
ool0003o0000o`0000?ooooo1_l00003ooooo`04o`000?ooooooooooooooo`Wo00001Oooool000;o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000006ooooo`;o00005oooool3o`00
01Oooooo0_l0000Hooooo`;o00005oooool4o`0001Kooooo0ol0000Gooooo`?o00005oooool3o`00
01Oooooo0ol0000Gooooo`?o00005oooool2o`0000Gooooo0002ooooo`04o`000?ooooooooooo`00
00Wooooo0_l00006ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo0ol00002ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo0003ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool00oooool001Oooooo00?o
0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`005oooool00ol0
003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`2;ooooo`;o00001Oooool001Oooooo00?o0000ooooooooool0
ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`03ooooo`00
5oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0
0oooool001Oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo00?ooooo000Gooooo`03o`000?oooooooooo07cooooo1Ol0001nooooo`;o00001Oooool0
01Oooooo00?o0000ooooooooool0OOooool4o`0007oooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0OOooool3o`00083ooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oo
oooooooo00?ooooo000Gooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo08cooooo
00?o0000ooooooooool0L?ooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooo
ooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo09;o
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`03ooooo`000oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo00?ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`03ooooo`000_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool000;o
oooo00Co0000oooooooooooo00001oooool4o`0000Kooooo0_l0002Gooooo`Co0000I?ooool3o`00
00Gooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2Gooooo`?o0000I_ooool00ol0003oooooooooo`03ooooo`000_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Uoooool2o`00
00;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`03ooooo`000oooool2o`0000[o
oooo0_l00006ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo09kooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`2Pooooo`;o0000G_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3o
ooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0Xoooool2o`00
05_ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool2o`0000Go
oooo000Gooooo`03o`000?oooooooooo0:Kooooo0_l0001Hooooo`03o`000?oooooooooo00?ooooo
000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool0
0ol0003oooooooooo`2Yooooo`;o0000EOooool00ol0003oooooooooo`03ooooo`005oooool00ol0
003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooooooo
ool0[?ooool2o`0005;ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0
[oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oo
oooooooo0;3ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03ooooo`005oooool0
0ol0003oooooooooo`2`ooooo`Co0000Boooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo
0;7ooooo0ol0001<ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0;7o
oooo0_l00002ooooo`;o0000BOooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool001Oooooo00?o
0000ooooooooool0^?ooool2o`0004Kooooo00?o0000ooooooooool00oooool001Oooooo00?o0000
ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo
0;_ooooo0_l00013ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oo
oooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`2nooooo`;o0000
?oooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`32ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0a?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0<Go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03ooooo`000oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool0aoooool2o`0003Oooooo
00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?o
oooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0<[ooooo0_l0000dooooo`03o`000?oooooooooo00?ooooo0002ooooo`04
o`000?ooooooooooo`0000Sooooo0ol00006ooooo`;o0000boooool4o`00033ooooo0ol00005oooo
o`000_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`3;ooooo`Co0000<Oooool00ol0003oooooooooo`03ooooo`000_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`3;ooooo`;o0000<oooool00ol0003oooooooooo`03ooooo`000oooool2o`0000Wooooo0ol00006
ooooo`03o`000?oooooooooo0<cooooo00Co0000oooooooooooooooo0_l0000^ooooo`03o`000?oo
oooooooo00?ooooo000Gooooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3Dooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0e_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0=Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`3Iooooo`;o00009?ooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool0
0ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03
o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o
0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0h_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3Tooooo`Co00005oooool2o`0000Go
oooo000Gooooo`03o`000?oooooooooo0>Gooooo0ol0000Hooooo`03o`000?oooooooooo00?ooooo
000Gooooo`03o`000?oooooooooo0>Gooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0>cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7o
oooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0koooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Ooo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3booooo`03o`000?oooooo
oooo00[ooooo0_l00005ooooo`005oooool00ol0003oooooooooo`3eooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0mOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`3oooooo`7ooooo00?o0000ooooooooool00oooool000kooooo0ol00006ooooo`03o`000?oooooo
oooo0?_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`003oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03ooooo`003oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`000005ooooo`003oooool00ol0003ooooo
ooooo`05oooooooo00001Ol00005ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000>
ooooo`;o0000oooooolAooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Indirect threespom", "Subsubsection"],

Cell[BoxData[
    \(\([b, d, e1, e2, e3, n1, n2, n3]\)\)], "Input"],

Cell[BoxData[
    \(DataEigenvalueSpom[b_, d_, e1_, e2_, e3_, n1_, n2_, n3_] := 
      Module[{\[Lambda]Po, \[Lambda]T}, \[Lambda]Po = 
          Eigenvalues[ThreePomPoMatrix[b, d, e1, e2, e3, n1, n2, n3], 
            1]; \[Lambda]T = 
          Eigenvalues[ThreePomTMatrix[b, d, e1, e2, e3, n1, n2, n3], 
            1]; {\[Lambda]Po, \[Lambda]T, \[Lambda]T\/\[Lambda]Po}]\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DataEigenvalueSpom[1.1, 0.2, 0.4, 0.3, 0.2, 5, 4, 4]\)], "Input"],

Cell[BoxData[
    \({{0.9513366967409966`}, {0.8146531879689031`}, \
{0.8563247804480458`}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Eigenvalues[ThreePomTMatrix[b, d, e1, e2, e3, n1, n2, n3], 
      1]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{Eigenvalues[ThreePomTMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 1], 
        Eigenvalues[ThreePomPoMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 
          1]}, {d, 0, 1}, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
      Frame \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36627 m
.01975 .39417 L
.04057 .4253 L
.0515 .43761 L
.06168 .44726 L
.08481 .46438 L
.10625 .47606 L
.12575 .48429 L
.14755 .49155 L
.16768 .49689 L
.20801 .50482 L
.22767 .50772 L
.24933 .51037 L
.29163 .5143 L
.33234 .51696 L
.35453 .51807 L
.37563 .51895 L
.41573 .52023 L
.43639 .52072 L
.45841 .52113 L
.48089 .52146 L
.49119 .52157 L
.50207 .52167 L
.51212 .52175 L
.52315 .52181 L
.52799 .52183 L
.53318 .52185 L
.53808 .52186 L
.54255 .52187 L
.54495 .52188 L
.5476 .52188 L
.54893 .52188 L
.55036 .52188 L
.55172 .52188 L
.55296 .52188 L
.55412 .52189 L
.5552 .52189 L
.55638 .52188 L
.55765 .52188 L
.55898 .52188 L
.56024 .52188 L
.56259 .52188 L
.56523 .52188 L
.56803 .52187 L
.57305 .52186 L
.57845 .52184 L
.58439 .52182 L
.59506 .52177 L
.60481 .5217 L
.62674 .52151 L
Mistroke
.64672 .52127 L
.66849 .52095 L
.71122 .52011 L
.75237 .51901 L
.79608 .5175 L
.83821 .51564 L
.87874 .51338 L
.92185 .51035 L
.96336 .50661 L
1 .50241 L
Mfstroke
0 .48836 m
.01975 .50568 L
.04057 .52911 L
.06168 .54635 L
.07365 .55381 L
.08481 .55963 L
.10625 .56846 L
.12575 .57453 L
.14586 .57938 L
.16768 .58347 L
.18851 .58654 L
.21059 .58912 L
.25031 .59253 L
.27069 .59383 L
.29262 .59498 L
.31331 .59588 L
.3359 .59669 L
.3776 .59781 L
.39825 .59824 L
.42027 .59861 L
.44125 .5989 L
.46394 .59915 L
.48585 .59934 L
.506 .59948 L
.52577 .59957 L
.53699 .59962 L
.54747 .59965 L
.55272 .59966 L
.55844 .59967 L
.56384 .59968 L
.56642 .59968 L
.56884 .59968 L
.57118 .59968 L
.57333 .59968 L
.57571 .59969 L
.57697 .59969 L
.57828 .59969 L
.57948 .59969 L
.58077 .59969 L
.58198 .59969 L
.58308 .59969 L
.58437 .59969 L
.5851 .59969 L
.58577 .59969 L
.58701 .59969 L
.58832 .59969 L
.59098 .59968 L
.5935 .59968 L
.59823 .59968 L
.60332 .59967 L
Mistroke
.60887 .59966 L
.61885 .59964 L
.6281 .59962 L
.64969 .59953 L
.66924 .59943 L
.68949 .59929 L
.71137 .59911 L
.75448 .59864 L
.79599 .59802 L
.83592 .59724 L
.87842 .59615 L
.91933 .59476 L
.96281 .59278 L
1 .5905 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Uooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00009Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000[ooooo`?o00001Oooool0
04;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000009?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool00000:oooool00ol0003oooooooooo`04ooooo`00@_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001oooool5o`0002Cooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Cooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01?oo
ool004;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Sooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00009Oooool01?l0003oooooooooool00007oooo
o`Co00009Oooool01?l0003oooooooooool00008ooooo`?o0000;?ooool00ol0003oooooooooo`04
ooooo`00@_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000009?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002Gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03o`000?oooooooooo00Cooooo0012ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Tooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Uooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000:_ooool2o`0000Kooooo0013oooo
o`;o00002Oooool3o`0002Kooooo0_l0000;ooooo`03o`000?oooooooooo02Cooooo0_l0000:oooo
o`;o00009_ooool2o`0000Wooooo0ol0000/ooooo`03o`000?oooooooooo00Cooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Goooooooo00001Ol00005oooo
o`005oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo
000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool0
0ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooo
ooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oo
oooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo
00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool2o`0000Gooooo000G
ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0
003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000oooooooo
ool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo
0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o
0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooo
oooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03oooo
o`005oooool00ol0003oooooooooo`3oooooo`;o00001Oooool001Oooooo00?o0000ooooooooool0
ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Ooo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000
ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`00
5oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o
0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooo
oooo0?oooooo0_l00005ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000oooo
ooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?o
oooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005ooo
ool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool000?ooooo0_l00004
ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`3oooooo`7ooooo00?o
0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
ooooool1ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool01?ooool2o`000?oooooo0ol00005ooooo`000_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3oooooo`7o
oooo00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00?ooooo0003ooooo`;o00002Oooool3o`0000Kooooo00?o0000ooooooooool0ooooool1ooooo`03
o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooo
ooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00ooo
ool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Goooo
o`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003o
ooooooooo`3oooooo`;o00001Oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooooooo
o`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool0
01Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03
o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooo
ooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0oooo
ool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0_l00005
ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`00
0?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1
ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000oooooooo
ool00oooool001Oooooo00?o0000ooooooooool0ooooool2o`0000Gooooo000Gooooo`03o`000?oo
oooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3o
ooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1oooo
o`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003o
ooooooooo`03ooooo`000oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Gooooo
00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`7ooooo
00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo00001oooool5o`0000Gooooo
00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool2o`000?oooooo0ol00005ooooo`00
0_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool0ooooool1ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00006ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`00
0oooool2o`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`7ooooo
00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oo
oooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03
ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`00
0?oooooooooo0?oooooo0_l00005ooooo`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o
0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooo
oooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03oooo
o`005oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo
00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oo
oooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3o
ooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool2o`00
00Gooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`00
5oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o
0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooo
oooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3ooooo
o`7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03
o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooo
ooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`;o00001Oooool001Oooooo00?o0000
ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo
0?oooooo0Oooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`3oooooo`7o
oooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo00?ooooo0003ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001_oo
ool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool00oooool000;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
ooooool1ooooo`03o`000?oooooooooo00?ooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003o
ooooooooo`03ooooo`000_ooool01?l0003oooooooooool00007ooooo`Co00001_ooool2o`000?oo
oooo0ol00005ooooo`000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Oo
oooo0_l0003oooooo`;ooooo00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooo0Oooool00ol0003o
ooooooooo`03ooooo`000oooool2o`0000[ooooo0_l00006ooooo`04o`000?ooooooooooo`000?oo
oooo00?o0000ooooooooool00oooool001Oooooo00Co0000oooooooooooo0000ooooool00ol0003o
ooooooooo`03ooooo`005oooool01Ol0003ooooooooooooooooo00000?kooooo00?o0000oooooooo
ool00oooool001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3kooooo`03o`00
0?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0nooo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?Wooooo0_l00005ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?Wooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3iooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0n?ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?Sooooo00?o0000ooooooooool00oooool001Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo00?ooooo000Goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0m_ooool00ol0003oooooooooo`03oooo
o`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?Gooooo00?o0000oooooooo
ool00oooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3cooooo`;o0000
1Oooool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3cooooo`03o`000?oo
oooooooo00?ooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0l_ooool0
0ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0?7ooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool03Oooool2o`000?7o
oooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`3^ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo013ooooo0_l0
003^ooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0joooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Coooo
o`;o0000j_ooool2o`0000Gooooo000Gooooo`03o`000?oooooooooo01Gooooo0_l0003Yooooo`03
o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
i_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Hooooo`;o0000i_oo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Jooooo`?o0000hoooool0
0ol0003oooooooooo`03ooooo`000oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Kooooo00?o0000ooooooooool07Oooool3o`000>3ooooo00?o0000ooooooooool00oooool000;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool08?ooool3o`000=gooooo00?o0000ooooooooool00oooool000;ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Tooooo`;o0000fooo
ool00ol0003oooooooooo`03ooooo`000_ooool01?l0003oooooooooool00008ooooo`?o00001_oo
ool3o`0002Gooooo0ol0003Fooooo`?o00001Oooool000;ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00009oooool4o`000=Co
oooo00?o0000ooooooooool00oooool000;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00000Zooooo`Go0000b_ooool6
o`0000Gooooo0003ooooo`;o00002Oooool3o`0000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0/ooooo`_o0000]Oooool:o`0000Gooooo00?o0000ooooooooool00oooool001Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`So0000X_ooool;o`0000oo
oooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`_o0000P_oooolEo`0001[ooooo00?o0000ooooooooool00oooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`18oooooaGo0000EooooolFo`0002oooooo00?o
0000ooooooooool00oooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1L
oooooeOo0000AOooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?Kooooo0_l00005ooooo`005oooool00ol0003oooooooooo`07ooooo`;o
0000moooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool02_oo
ool2o`000?Cooooo00?o0000ooooooooool00oooool001Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3aooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo
00gooooo0_l0003aooooo`03o`000?oooooooooo00?ooooo000Gooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooo
ooooo`0@ooooo`;o0000k_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0>[ooooo0_l00005ooooo`005oooool00ol0003oooooooooo`0C
ooooo`;o0000joooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Eoooo
o`?o0000j?ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Hooooo`;o
0000i_ooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Jooooo`?o0000
hoooool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Mooooo`Co0000gooo
ool00ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Qooooo`Go0000f_ooool0
0ol0003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0Vooooo`Ko0000e?ooool00ol0
003oooooooooo`03ooooo`005oooool00ol0003oooooooooo`0/ooooo`Go0000c_ooool2o`0000Go
oooo000Gooooo`03o`000?oooooooooo037ooooo4?l0002`oooooa3o00001Oooool001Oooooo00?o
0000ooooooooool0@OoooolIo`00087ooooo5_l0000?ooooo`03o`000?oooooooooo00?ooooo000G
ooooo`03o`000?oooooooooo05[oooooPOl0000Uooooo`03o`000?oooooooooo00?ooooo000Goooo
o`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`03ooooo`003_ooool3o`0000Ko
oooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00?ooooo000?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00?ooooo000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo000?ooooo`03o`000?oooooo
oooo00Goooooool00005o`0000Gooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool000ko
oooo0_l0003ooooooa7ooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0888029, -0.0764114, \
0.00385797, 0.00624232}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\((Eigenvalues[ThreePomTMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 1]/
        Eigenvalues[ThreePomPoMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 
          1])\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{Eigenvalues[ThreePomTMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 1]/
          Eigenvalues[ThreePomPoMatrix[1.1, d, 0.4, 0.3, 0.2, 5, 4, 4], 
            1]}, {m, 0, 1}, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
      Frame \[Rule] True]\)], "Input"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 810}},
AutoGeneratedPackage->None,
WindowSize->{532, 540},
WindowMargins->{{287, Automatic}, {Automatic, 36}},
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.48.1"->{
    Cell[1812, 55, 76, 1, 35, "Input",
      CellTags->"S5.48.1"]},
  "Outer"->{
    Cell[2027, 64, 148, 3, 51, "Input",
      CellTags->"Outer"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.48.1", 2626695, 44900},
  {"Outer", 2626776, 44903}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 33, 0, 50, "Section"],
Cell[1812, 55, 76, 1, 35, "Input",
  CellTags->"S5.48.1"],
Cell[1891, 58, 68, 1, 35, "Input"],
Cell[1962, 61, 62, 1, 35, "Input"],
Cell[2027, 64, 148, 3, 51, "Input",
  CellTags->"Outer"],
Cell[2178, 69, 42, 0, 26, "Text"],
Cell[2223, 71, 674, 10, 161, "Input"],
Cell[2900, 83, 355, 5, 127, "Input"],
Cell[3258, 90, 566, 10, 175, "Input"],
Cell[3827, 102, 53, 1, 47, "Input"],
Cell[3883, 105, 562, 9, 175, "Input"],
Cell[4448, 116, 44, 0, 28, "Text"],
Cell[4495, 118, 1052, 22, 255, "Input"],

Cell[CellGroupData[{
Cell[5572, 144, 33, 0, 29, "Subsubsection"],
Cell[5608, 146, 1823, 32, 287, "Input"],
Cell[7434, 180, 23889, 398, 4758, "Input"],
Cell[31326, 580, 108, 2, 95, "Input"],
Cell[31437, 584, 18873, 321, 2571, "Input"],
Cell[50313, 907, 1104393, 17252, 153390, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1154755, 18165, 25, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[1154805, 18169, 38, 0, 38, "Subsection"],
Cell[1154846, 18171, 204, 7, 116, "Text"],
Cell[1155053, 18180, 92, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[1155170, 18185, 86, 1, 51, "Input"],
Cell[1155259, 18188, 23459, 654, 194, 5067, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1178721, 18844, 130, 3, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1178888, 18852, 86, 1, 51, "Input"],
Cell[1178977, 18855, 24715, 733, 194, 6340, 502, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1203695, 19590, 130, 3, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1203874, 19599, 32, 0, 24, "Subsection"],
Cell[1203909, 19601, 46, 0, 26, "Text"],
Cell[1203958, 19603, 162, 7, 116, "Text"],
Cell[1204123, 19612, 43, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[1204191, 19616, 89, 1, 51, "Input"],
Cell[1204283, 19619, 57, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1204377, 19625, 59, 1, 35, "Input"],
Cell[1204439, 19628, 52, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1204528, 19634, 68, 1, 35, "Input"],
Cell[1204599, 19637, 23614, 723, 194, 6405, 506, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1228216, 20362, 130, 3, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1228383, 20370, 68, 1, 35, "Input"],
Cell[1228454, 20373, 23872, 778, 194, 7420, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1252329, 21153, 130, 3, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1252508, 21162, 34, 0, 24, "Subsection"],
Cell[1252545, 21164, 392, 12, 206, "Text"],
Cell[1252940, 21178, 49, 0, 26, "Text"],
Cell[1252992, 21180, 136, 3, 35, "Input"],

Cell[CellGroupData[{
Cell[1253153, 21187, 127, 3, 51, "Input"],
Cell[1253283, 21192, 55, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1253375, 21198, 102, 2, 51, "Input"],
Cell[1253480, 21202, 23072, 756, 194, 7208, 556, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276555, 21960, 130, 3, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1276722, 21968, 106, 2, 51, "Input"],
Cell[1276831, 21972, 23153, 715, 194, 6353, 503, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1299987, 22689, 130, 3, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1300166, 22698, 63, 0, 24, "Subsection"],

Cell[CellGroupData[{
Cell[1300254, 22702, 895, 14, 350, "Input"],
Cell[1301152, 22718, 20577, 597, 194, 4709, 397, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1321732, 23317, 130, 3, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1321923, 23327, 40, 0, 34, "Section"],
Cell[1321966, 23329, 454, 12, 65, "Input"],
Cell[1322423, 23343, 357, 8, 49, "Input"],

Cell[CellGroupData[{
Cell[1322805, 23355, 210, 3, 51, "Input"],
Cell[1323018, 23360, 509, 8, 152, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1323564, 23373, 157, 3, 35, "Input"],
Cell[1323724, 23378, 77, 1, 35, "Output"]
}, Open  ]],
Cell[1323816, 23382, 446, 9, 67, "Input"],

Cell[CellGroupData[{
Cell[1324287, 23395, 300, 5, 102, "Input"],
Cell[1324590, 23402, 1174, 18, 198, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1325801, 23425, 157, 3, 35, "Input"],
Cell[1325961, 23430, 77, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1326075, 23436, 1344, 20, 299, "Input"],
Cell[1327422, 23458, 77, 1, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1327548, 23465, 34, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[1327607, 23469, 32, 0, 38, "Subsection"],
Cell[1327642, 23471, 44, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[1327711, 23476, 565, 12, 230, "Input"],
Cell[1328279, 23490, 786, 16, 65, "Output"]
}, Open  ]],
Cell[1329080, 23509, 769, 13, 246, "Input"],
Cell[1329852, 23524, 44, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[1329921, 23529, 781, 15, 308, "Input"],
Cell[1330705, 23546, 1367, 24, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1332109, 23575, 946, 14, 527, "Input"],
Cell[1333058, 23591, 836, 12, 183, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1333931, 23608, 1035, 17, 476, "Input"],
Cell[1334969, 23627, 287, 4, 23, "Message"],
Cell[1335259, 23633, 287, 4, 23, "Message"],
Cell[1335549, 23639, 287, 4, 23, "Message"],
Cell[1335839, 23645, 330, 5, 35, "Message"],
Cell[1336172, 23652, 2009, 38, 73, "Output"],
Cell[1338184, 23692, 339, 6, 23, "Message"],
Cell[1338526, 23700, 339, 6, 23, "Message"],
Cell[1338868, 23708, 339, 6, 23, "Message"],
Cell[1339210, 23716, 382, 7, 35, "Message"],
Cell[1339595, 23725, 1810, 35, 181, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1341442, 23765, 78, 1, 35, "Input"],
Cell[1341523, 23768, 1114, 16, 109, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1342686, 23790, 34, 0, 24, "Subsection"],
Cell[1342723, 23792, 71, 1, 51, "Input"],

Cell[CellGroupData[{
Cell[1342819, 23797, 1384, 22, 548, "Input"],
Cell[1344206, 23821, 386, 6, 35, "Message"],
Cell[1344595, 23829, 1796, 26, 269, "Output"]
}, Closed]],
Cell[1346406, 23858, 44, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[1346475, 23863, 1987, 31, 627, "Input"],
Cell[1348465, 23896, 287, 4, 23, "Message"],
Cell[1348755, 23902, 287, 4, 23, "Message"],
Cell[1349045, 23908, 287, 4, 23, "Message"],
Cell[1349335, 23914, 330, 5, 35, "Message"],
Cell[1349668, 23921, 18543, 316, 1945, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1368272, 24244, 36, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[1368333, 24248, 32, 0, 38, "Subsection"],
Cell[1368368, 24250, 71, 1, 51, "Input"],

Cell[CellGroupData[{
Cell[1368464, 24255, 713, 10, 363, "Input"],
Cell[1369180, 24267, 1155, 21, 77, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1370372, 24293, 347, 7, 149, "Input"],
Cell[1370722, 24302, 327, 9, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1371086, 24316, 153, 3, 67, "Input"],
Cell[1371242, 24321, 7145, 123, 153, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1378424, 24449, 1234, 21, 514, "Input"],
Cell[1379661, 24472, 287, 4, 23, "Message"],
Cell[1379951, 24478, 287, 4, 23, "Message"],
Cell[1380241, 24484, 278, 4, 36, "Message"],
Cell[1380522, 24490, 278, 4, 36, "Message"],
Cell[1380803, 24496, 408, 6, 49, "Message"],
Cell[1381214, 24504, 278, 4, 36, "Message"],
Cell[1381495, 24510, 329, 5, 35, "Message"],
Cell[1381827, 24517, 382, 6, 37, "Message"],
Cell[1382212, 24525, 355, 5, 36, "Message"],
Cell[1382570, 24532, 336, 5, 35, "Message"],
Cell[1382909, 24539, 287, 4, 23, "Message"],
Cell[1383199, 24545, 330, 5, 35, "Message"],
Cell[1383532, 24552, 20152, 303, 3488, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1403733, 24861, 34, 0, 24, "Subsection"],
Cell[1403770, 24863, 71, 1, 51, "Input"],
Cell[1403844, 24866, 561, 10, 209, "Input"],

Cell[CellGroupData[{
Cell[1404430, 24880, 1223, 19, 383, "Input"],
Cell[1405656, 24901, 4050, 72, 119, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1409743, 24978, 347, 7, 135, "Input"],
Cell[1410093, 24987, 728, 14, 199, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1410858, 25006, 153, 3, 67, "Input"],
Cell[1411014, 25011, 66630, 1047, 325, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1477681, 26063, 2231, 35, 667, "Input"],
Cell[1479915, 26100, 287, 4, 23, "Message"],
Cell[1480205, 26106, 287, 4, 23, "Message"],
Cell[1480495, 26112, 287, 4, 23, "Message"],
Cell[1480785, 26118, 330, 5, 35, "Message"],
Cell[1481118, 26125, 278, 4, 36, "Message"],
Cell[1481399, 26131, 520, 7, 54, "Message"],
Cell[1481922, 26140, 278, 4, 36, "Message"],
Cell[1482203, 26146, 456, 6, 57, "Message"],
Cell[1482662, 26154, 278, 4, 36, "Message"],
Cell[1482943, 26160, 329, 5, 35, "Message"],
Cell[1483275, 26167, 520, 7, 54, "Message"],
Cell[1483798, 26176, 336, 5, 35, "Message"],
Cell[1484137, 26183, 1086828, 17126, 125392, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2571026, 43316, 25, 0, 34, "Section"],

Cell[CellGroupData[{
Cell[2571076, 43320, 65, 0, 29, "Subsubsection"],
Cell[2571144, 43322, 371, 6, 120, "Input"],
Cell[2571518, 43330, 52, 1, 51, "Input"],
Cell[2571573, 43333, 176, 3, 67, "Input"],
Cell[2571752, 43338, 52, 1, 51, "Input"],
Cell[2571807, 43341, 1415, 24, 281, "Input"],

Cell[CellGroupData[{
Cell[2573247, 43369, 71, 1, 35, "Input"],
Cell[2573321, 43372, 28277, 764, 194, 9310, 525, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2601601, 44138, 130, 3, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2601780, 44147, 43, 0, 21, "Subsubsection"],
Cell[2601826, 44149, 67, 1, 35, "Input"],
Cell[2601896, 44152, 389, 7, 120, "Input"],

Cell[CellGroupData[{
Cell[2602310, 44163, 85, 1, 35, "Input"],
Cell[2602398, 44166, 105, 2, 35, "Output"]
}, Open  ]],
Cell[2602518, 44171, 101, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[2602644, 44177, 264, 4, 67, "Input"],
Cell[2602911, 44183, 22420, 673, 194, 5721, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2625334, 44858, 130, 3, 35, "Output"]
}, Open  ]],
Cell[2625479, 44864, 187, 3, 52, "Input"],

Cell[CellGroupData[{
Cell[2625691, 44871, 267, 4, 67, "Input"],
Cell[2625961, 44877, 42, 1, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

